@@ -9,12 +9,12 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/admin/modules/blocks.php,v $
-  $Revision: 9.41 $
+  $Revision: 9.41.2.4 $
   $Author: nanocaiordo $
-  $Date: 2007/10/03 13:51:39 $
+  $Date: 2010/03/18 10:22:32 $
 **********************************************/
 if (!defined('ADMIN_PAGES')) { exit; }
-if (!can_admin()) { die('Access Denied'); }
+if (!can_admin('blocks')) { die('Access Denied'); }
 $pagetitle .= ' '._BC_DELIM.' '._BLOCKSADMIN;
 require_once(CORE_PATH.'nbbcode.php');
 if (isset($_GET['change'])) {
@@ -53,6 +53,8 @@ if (isset($_GET['change'])) {
 		$sides = array('l','c','r','d','n');
 		$count = count($_POST['id']);
 		$blocks = blocks_list();
+		$mid = intval($_POST['mid']);
+		$module = $db->sql_escape_string($_POST['module']);
 		for ($i=0; $i<$count; ++$i) {
 			if (!intval($_POST['id'][$i])) continue;
 			if ($_POST['id'][$i] < 0 ) {
@@ -60,8 +62,6 @@ if (isset($_GET['change'])) {
 				$pos=1;
 			} else {
 				$bid = intval($_POST['id'][$i]);
-				$mid = intval($_POST['mid'][$i]);
-				$module = $db->sql_escape_string($_POST['module'][$i]);
 				if ($side == 'n') {
 					$db->query('DELETE FROM '.$prefix."_blocks_custom WHERE bid=$bid AND mid=$mid");
 				} else if (empty($blocks[$module][$bid])) {
@@ -80,21 +80,12 @@ if (isset($_GET['change'])) {
 
 function BlocksAdmin()
 {
-	global $bgcolor2, $bgcolor3, $prefix, $db, $currentlang, $multilingual, $cpgtpl, $modheader, $ThemeSel;
-	$blocks_theme = 'default';
-	# will be removed the next release
-	if ($ThemeSel != ' default'
-		&& file_exists('themes/'.$ThemeSel.'/style/adminblocks.css')
-		&& file_exists('themes/'.$ThemeSel.'/javascript/adminblocks.js')
-		&& file_exists('themes/'.$ThemeSel.'/images/drag.png'))
-	{
-			$blocks_theme = $ThemeSel;
-	}
+	global $bgcolor2, $bgcolor3, $prefix, $db, $currentlang, $multilingual, $cpgtpl, $modheader;
 	$modheader .= '
 <script type="text/javascript" src="includes/javascript/framework.js"></script>
-<script type="text/javascript" src="themes/'.$blocks_theme.'/javascript/adminblocks.js"></script>
-<link rel="stylesheet" href="themes/'.$blocks_theme.'/style/tabletree.css" type="text/css" media="screen" />
-<link rel="stylesheet" href="themes/'.$blocks_theme.'/style/adminblocks.css" type="text/css" media="screen" />';
+<script type="text/javascript" src="themes/default/javascript/adminblocks.js"></script>
+<link rel="stylesheet" href="themes/default/style/tabletree.css" type="text/css" media="screen" />
+<link rel="stylesheet" href="themes/default/style/adminblocks.css" type="text/css" media="screen" />';
 	require('header.php');
 	GraphicAdmin('_AMENU1');
 
@@ -155,7 +146,7 @@ function BlocksAdmin()
 	while($row = $db->sql_fetchrow($result, SQL_ASSOC)) {
 		$blocks[$row['bid']] = $row;
 		if (defined($row['title'])) $row['title'] = constant($row['title']);
-		$all[$row['title']] = $row;
+		$all[$row['title'].$row['bid']] = $row;
 	}
 	$bgcolor = $bgcolor3;
 	$visblocks = array();
