@@ -9,12 +9,12 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/admin/modules/modules.php,v $
-  $Revision: 9.50 $
+  $Revision: 9.50.2.4 $
   $Author: nanocaiordo $
-  $Date: 2007/12/18 11:37:21 $
+  $Date: 2011/10/03 10:45:57 $
 **********************************************/
 if (!defined('ADMIN_PAGES')) { exit; }
-if (!can_admin()) { die('Access Denied'); }
+if (!can_admin('modules')) { die('Access Denied'); }
 
 if (isset($_GET['change'])) {
 	if ($CPG_SESS['admin']['page'] != 'modules') { cpg_error(_ERROR_BAD_LINK, _SEC_ERROR); }
@@ -154,7 +154,7 @@ else if (isset($_GET['upgrade'])) {
 		cpg_error(_UPGRADEFAILED.': couldn\'t load installer');
 	}
 	require(CORE_PATH.'classes/installer.php');
-	$installer =& new cpg_installer(true, true);
+	$installer = new cpg_installer(true, true);
 	$module = new $class;
 	if ($module->upgrade($version)) {
 		if (!$installer->install()) {
@@ -272,7 +272,7 @@ else {
 		}
 		if (class_exists($class)) {
 			require(CORE_PATH.'classes/installer.php');
-			$installer =& new cpg_installer(true, true);
+			$installer = new cpg_installer(true, true);
 			$module = new $class;
 			$addmod = $module->install();
 			if (!$addmod) { cpg_error($module->description, 'Install Error'); }
@@ -287,16 +287,18 @@ else {
 			unset($_SESSION['CPG_ADMIN']);
 		}
 		$result = $db->sql_query('SELECT bid, bposition FROM '.$prefix.'_blocks WHERE active=1');
-		$in_modules = array();
-		$l = $c = $r = $d = 1;
-		while ($row = $db->sql_fetchrow($result, SQL_NUM)) {
-			$in_modules[] = "($row[0], $insertmid, '$row[1]', ".$$row[1].")";
-			++$$row[1];
+		if ($db->sql_numrows($result)) {
+			$in_modules = array();
+			$l = $c = $r = $d = 1;
+			while ($row = $db->sql_fetchrow($result, SQL_NUM)) {
+				$in_modules[] = "($row[0], $insertmid, '$row[1]', ".$$row[1].")";
+				++$$row[1];
+			}
+			$db->sql_query('INSERT INTO '.$prefix.'_blocks_custom (bid, mid, side, weight) VALUES '.implode(',', $in_modules));
+			Cache::array_delete('blocks_list');
 		}
 		$db->sql_freeresult($result);
-		$db->sql_query('INSERT INTO '.$prefix.'_blocks_custom (bid, mid, side, weight) VALUES '.implode(',', $in_modules));
 		Cache::array_delete('MAIN_CFG');
-		Cache::array_delete('blocks_list');
 		Cache::array_delete('waitlist');
 		Cache::array_delete('adlinks');
 		cpg_error("The module \"$class\" has been properly installed, have a blast using it!", 'Module Installed', adminlink('modules'));
@@ -313,7 +315,7 @@ else {
 				$CPG_SESS['admin']['uninstall'] = '';
 				unset($CPG_SESS['admin']['uninstall']);
 				require(CORE_PATH.'classes/installer.php');
-				$installer =& new cpg_installer(true, true);
+				$installer = new cpg_installer(true, true);
 				$module = new $class;
 				$module->uninstall();
 				if (!$installer->install()) {
@@ -348,7 +350,7 @@ else {
 			$db->sql_query("DELETE FROM {$prefix}_modules WHERE title='{$row['title']}'");
 			$db->optimize_table($prefix.'_modules');
 			$db->sql_query("DELETE FROM {$prefix}_blocks_custom WHERE mid='{$row['mid']}'");
-			$db->optimize_table($prefix.'blocks_custom');
+			$db->optimize_table($prefix.'_blocks_custom');
 			Cache::array_delete('blocks_list');
 		} else {
 			$mods[$row['title']] = $row;
@@ -358,31 +360,31 @@ else {
 	while ($file = readdir($handle)) {
 		if (!ereg('[.]',$file) && $file != 'CVS') {
 			$class = "$file";
-			if ($class != '' && !isset($mods[$class])) {
-				if (file_exists('modules/'.$class.'/index.php')) {
-					$inst_file = (is_file('modules/'.$class.'/sql/cpg_inst.php') ? 'modules/'.$class.'/sql/cpg_inst.php' : (is_file('modules/'.$class.'/cpg_inst.php') ? 'modules/'.$class.'/cpg_inst.php' : false));
-					if ($inst_file) {
-						include($inst_file);
-						if (class_exists($class)) {
-							$module = new $class;
-							$mods[$class] = array('mid' => 0, 'title' => $class, 'custom_title' => $module->description, 'active' => 0, 'view' => 0, 'inmenu' => 1, 'uninstall' => -1);
-						} else {
-							$mods[$class] = array('mid' => 0, 'title' => $class, 'custom_title' => "modules/$class/cpg_inst.php is missing class: $class", 'active' => 0, 'view' => 0, 'inmenu' => 1, 'uninstall' => 0);
-						}
+			if ($class != '' && !isset($mods[$class]) && file_exists('modules/'.$class.'/index.php')) {
+				$inst_file = (is_file('modules/'.$class.'/sql/cpg_inst.php') ? 'modules/'.$class.'/sql/cpg_inst.php' : (is_file('modules/'.$class.'/cpg_inst.php') ? 'modules/'.$class.'/cpg_inst.php' : false));
+				if ($inst_file) {
+					include($inst_file);
+					if (class_exists($class)) {
+						$module = new $class;
+						$mods[$class] = array('mid' => 0, 'title' => $class, 'custom_title' => $module->description, 'active' => 0, 'view' => 0, 'inmenu' => 1, 'uninstall' => -1);
 					} else {
-						$db->sql_query("INSERT INTO ".$prefix."_modules (title) VALUES ('$class')");
-						$mods[$class] = array('mid' => $db->sql_nextid('mid'), 'title' => $class, 'custom_title' => '', 'active' => 0, 'view' => 0, 'inmenu' => 1, 'uninstall' => 0);
-						$result = $db->sql_query('SELECT bid, bposition FROM '.$prefix.'_blocks WHERE active=1');
+						$mods[$class] = array('mid' => 0, 'title' => $class, 'custom_title' => "modules/$class/cpg_inst.php is missing class: $class", 'active' => 0, 'view' => 0, 'inmenu' => 1, 'uninstall' => 0);
+					}
+				} else {
+					$db->sql_query("INSERT INTO ".$prefix."_modules (title) VALUES ('$class')");
+					$mods[$class] = array('mid' => $db->sql_nextid('mid'), 'title' => $class, 'custom_title' => '', 'active' => 0, 'view' => 0, 'inmenu' => 1, 'uninstall' => 0);
+					$result = $db->sql_query('SELECT bid, bposition FROM '.$prefix.'_blocks WHERE active=1');
+					if ($db->sql_numrows($result)) {
 						$in_modules = array();
 						$l = $c = $r = $d = 1;
 						while ($row = $db->sql_fetchrow($result, SQL_NUM)) {
 							$in_modules[] = "($row[0], '{$mods[$class]['mid']}', '$row[1]', ".$$row[1].")";
 							++$$row[1];
 						}
-						$db->sql_freeresult($result);
 						$db->sql_query('INSERT INTO '.$prefix.'_blocks_custom (bid, mid, side, weight) VALUES '.implode(',', $in_modules));
 						Cache::array_delete('blocks_list');
 					}
+					$db->sql_freeresult($result);
 				}
 			}
 		}
