@@ -9,9 +9,9 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/admin/modules/security.php,v $
-  $Revision: 1.20 $
+  $Revision: 1.20.2.8 $
   $Author: nanocaiordo $
-  $Date: 2007/12/16 09:22:49 $
+  $Date: 2012/01/21 04:06:05 $
 **********************************************/
 /*
 	Future dev notes regarding IPv6
@@ -42,7 +42,7 @@
 */
 
 if (!defined('ADMIN_PAGES')) { exit; }
-if (!can_admin()) { die('Access Denied'); }
+if (!can_admin('security')) { die('Access Denied'); }
 
 $pagetitle .= ' '._BC_DELIM.' Security';
 $page = isset($_GET['page']) ? intval($_GET['page']) : 1;
@@ -76,7 +76,7 @@ $ids = array(
 	array(_FLOODING, 'flooding', 'floods'),
 	array('IP\'s', 'ips', 'ips'),
 	array(_HTTPREFERERS, 'referers', 'referers'),
-	array('Unkown User-Agents', 'uas', 'uas'),
+	array('Unknown User-Agents', 'uas', 'uas'),
 	array('IPs Shield', 'shield', 'shields')
 );
 
@@ -150,11 +150,11 @@ if (isset($_GET['bots'])) {
 				if ($ip === false) { cpg_error('Nothing specified'); }
 				$ip_len = strlen($ip);
 				if ($ip_len == 4) {
-					list(,$ip) = unpack('N',$ip);
+					$ip = ip2long32(inet_ntop($ip));
 					if (empty($ip2)) {
 						$db->sql_query('INSERT INTO '.$prefix."_security (ban_ipv4_s, ban_string, ban_type) VALUES ('$ip', '$ua_name', 1)");
 					} else {
-						list(,$ip2) = unpack('N',$ip2);
+						$ip2 = ip2long32(inet_ntop($ip2));
 						if ($ip2 < $ip) { $ip1 = $ip2; $ip2 = $ip; }
 						else { $ip1 = $ip; }
 						$db->sql_query('INSERT INTO '.$prefix."_security (ban_ipv4_s, ban_ipv4_e, ban_string, ban_type) VALUES ($ip1, $ip2, '$ua_name', 1)");
@@ -373,11 +373,11 @@ else if (isset($_GET['ips'])) {
 
 		$details = $db->sql_escape_string($_POST['description']);
 		if ($ip_len == 4) {
-			list(,$ip) = unpack('N',$ip);
+			$ip = ip2long32(inet_ntop($ip));
 			if (empty($ip2)) {
 				$db->sql_query('INSERT INTO '.$prefix."_security (ban_ipv4_s, ban_type, ban_time, ban_details) VALUES ('$ip', 0, -1, '$details')");
 			} else {
-				list(,$ip2) = unpack('N',$ip2);
+				$ip2 = ip2long32(inet_ntop($ip2));
 				if ($ip2 < $ip) { $ip1 = $ip2; $ip2 = $ip; }
 				else { $ip1 = $ip; }
 				$db->sql_query('INSERT INTO '.$prefix."_security (ban_ipv4_s, ban_ipv4_e, ban_type, ban_time, ban_details) VALUES ($ip1, $ip2, 0, -1, '$details')");
@@ -422,7 +422,7 @@ else if (isset($_GET['ip'])) {
 	$ip = inet_pton($_GET['ip']);
 	$ipn = $db->binary_safe($ip);
 	if (strlen($ip) == 4) {
-		list(,$ipv4) = unpack('N',$ip);
+		$ipv4 = ip2long32(inet_ntop($ip));
 		$result = $db->query('SELECT * FROM '.$prefix."_security WHERE ban_type IN(0,7) AND (ban_ipn=$ipn OR ban_ipv4_s='$ipv4')");
 	} else if (strlen($ip) == 16) {
 		$result = $db->query('SELECT * FROM '.$prefix."_security WHERE ban_type IN(0,7) AND ban_ipn=$ipn");
@@ -437,7 +437,7 @@ else if (isset($_GET['ip'])) {
 				$ip .= '<br />CIDR: '.long2ip($row['ban_ipv4_s'])."/$cidr";
 			}
 		} else {
-			$ip = inet_ntop(substr($row['ban_ipn'],0,-1));
+			$ip = inet_ntop($row['ban_ipn']);
 			if (!empty($row['log'])) {
 				$log = unserialize($row['log']);
 				for ($i=0; $i<5; ++$i) {
@@ -467,7 +467,7 @@ else if (isset($_GET['shields'])) {
 				$ip = inet_pton($ip);
 				$ip_len = strlen($ip);
 				if ($ip_len == 4) {
-					list(,$ip) = unpack('N',$ip);
+					$ip = ip2long32(inet_ntop($ip));
 					$db->sql_query('DELETE FROM '.$prefix."_security WHERE ban_ipv4_s=$ip AND ban_type=8");
 				} else if ($ip_len == 16) {
 					//mac = substr($ip,-8)
@@ -506,11 +506,11 @@ else if (isset($_GET['shields'])) {
 
 			$details = $db->sql_escape_string($_POST['description']);
 			if ($ip_len == 4) {
-				list(,$ip) = unpack('N',$ip);
+				$ip = ip2long32(inet_ntop($ip));
 				if (empty($ip2)) {
 					$db->sql_query('INSERT INTO '.$prefix."_security (ban_ipv4_s, ban_type, ban_time, ban_details) VALUES ('$ip', 8, ".gmtime().", '$details')");
 				} else {
-					list(,$ip2) = unpack('N',$ip2);
+					$ip2 = ip2long32(inet_ntop($ip2));
 					if ($ip2 < $ip) { $ip1 = $ip2; $ip2 = $ip; }
 					else { $ip1 = $ip; }
 					$db->sql_query('INSERT INTO '.$prefix."_security (ban_ipv4_s, ban_ipv4_e, ban_type, ban_time, ban_details) VALUES ($ip1, $ip2, 8, ".gmtime().", '$details')");
@@ -557,7 +557,7 @@ else if (isset($_GET['shield'])) {
 	$ip = inet_pton($_GET['shield']);
 	$ipn = $db->binary_safe($ip);
 	if (strlen($ip) == 4) {
-		list(,$ipv4) = unpack('N',$ip);
+		$ipv4 = ip2long32(inet_ntop($ip));
 		$result = $db->query('SELECT * FROM '.$prefix."_security WHERE ban_type=8 AND ban_ipv4_s='$ipv4'");
 	} else if (strlen($ip) == 16) {
 		$result = $db->query('SELECT * FROM '.$prefix."_security WHERE ban_type=8 AND ban_ipn=$ipn");
@@ -572,7 +572,7 @@ else if (isset($_GET['shield'])) {
 				$ip .= '<br />CIDR: '.long2ip($row['ban_ipv4_s'])."/$cidr";
 			}
 		} else {
-			$ip = inet_ntop(substr($row['ban_ipn'],0,-1));
+			$ip = inet_ntop($row['ban_ipn']);
 		}
 		if (!empty($row['log'])) {
 			$log = unserialize($row['log']);
@@ -608,7 +608,7 @@ else if (isset($_GET['referers'])) {
 		}
 		if (!empty($_POST['new_entry'])) {
 			$new_entry = $db->sql_escape_string($_POST['new_entry']);
-			if (!strpos($new_entry,'.')) { cpg_error(sprintf(_ERROR_BAD_FORMAT, _HTTPREFERERS)); }
+			if (FALSE === strpos($new_entry,'.')) { cpg_error(sprintf(_ERROR_BAD_FORMAT, _HTTPREFERERS)); }
 			$db->sql_query('INSERT INTO '.$prefix."_security (ban_string, ban_type) VALUES ('$new_entry', 3)");
 		}
 		$db->optimize_table($prefix.'_security');
@@ -744,12 +744,12 @@ else {
 	$cpgtpl->assign_block_vars('settings', array(
 		'L_NAME' => _FLOODING_TIP,
 		'L_ID' => 'delay',
-		'S_VALUES' => select_box('_security[delay]', $MAIN_CFG['_security']['delay'], array(1=>'Tight',2=>'Loose'))
+		'S_VALUES' => select_box('_security[delay]', $MAIN_CFG['_security']['delay'], array(1=>'Tight',2=>'Medium',4=>'Loose'))
 	));
 	$cpgtpl->assign_block_vars('settings', array(
 		'L_NAME' => _BAN_TIP,
 		'L_ID' => 'bantime',
-		'S_VALUES' => select_box('_security[bantime]', $MAIN_CFG['_security']['bantime'], array(900=>'15 Minutes',3600=>'1 Hour',43200=>'12 Hours',86400=>'24 Hours'))
+		'S_VALUES' => select_box('_security[bantime]', $MAIN_CFG['_security']['bantime'], array(60=>'1 Minute',300=>'5 Minutes',900=>'15 Minutes',3600=>'1 Hour',43200=>'12 Hours',86400=>'24 Hours'))
 	));
 	$cpgtpl->assign_block_vars('settings', array(
 		'L_NAME' => _AUTO_UNBAN_TIP,
