@@ -9,9 +9,9 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/admin/modules/settings.php,v $
-  $Revision: 9.38 $
+  $Revision: 9.38.2.1 $
   $Author: nanocaiordo $
-  $Date: 2008/01/27 12:12:04 $
+  $Date: 2008/11/06 10:51:43 $
 **********************************************/
 if (!defined('ADMIN_PAGES')) { exit; }
 if (!can_admin()) { die('Access Denied'); }
@@ -134,13 +134,14 @@ else {
 		'S_ACTION' => adminlink('&amp;s='.$section)
 	));
 
+	$sc = count($section_t);
 	foreach ($section_t as $key => $value) {
 		$cpgtpl->assign_block_vars('menu', array(
 			'B_URL' => $section != $key,
 			'S_URL' => adminlink('&amp;s='.$key),
 			'S_VALUE' => $value,
 			'S_KEY' => $key,
-			'B_NEXT' => next($section_t)
+			'B_NEXT' => --$sc > 0
 		));
 	}
 
