@@ -17,9 +17,9 @@
  * @author Brent R. Matzelle
  * @copyright 2001 - 2003 Brent R. Matzelle
   $Source: /cvs/html/includes/classes/phpmailer.php,v $
-  $Revision: 9.8 $
+  $Revision: 9.8.8.4 $
   $Author: nanocaiordo $
-  $Date: 2006/12/16 21:56:16 $
+  $Date: 2012/01/21 12:50:38 $
 */
 
 if (!defined('CPG_NUKE')) { exit; }
@@ -103,7 +103,7 @@ class PHPMailer
 	var $AltBody		   = '';
 
 	/**
-	 * Sets word wrapping on the body of the message to a given number of 
+	 * Sets word wrapping on the body of the message to a given number of
 	 * characters.
 	 * @var int
 	 */
@@ -120,7 +120,7 @@ class PHPMailer
 	 * @var string
 	 */
 	var $Sendmail		  = '/usr/sbin/sendmail';
-	
+
 	/**
 	 *  Holds PHPMailer version.
 	 *  @var string
@@ -187,7 +187,7 @@ class PHPMailer
 	var $Password	 = '';
 
 	/**
-	 *  Sets the SMTP server timeout in seconds. This function will not 
+	 *  Sets the SMTP server timeout in seconds. This function will not
 	 *  work with the win32 version.
 	 *  @var int
 	 */
@@ -200,9 +200,9 @@ class PHPMailer
 	var $SMTPDebug	= false;
 
 	/**
-	 * Prevents the SMTP connection from being closed after each mail 
-	 * sending.  If this is set to true then to close the connection 
-	 * requires an explicit call to SmtpClose(). 
+	 * Prevents the SMTP connection from being closed after each mail
+	 * sending.  If this is set to true then to close the connection
+	 * requires an explicit call to SmtpClose().
 	 * @var bool
 	 */
 	var $SMTPKeepAlive = false;
@@ -223,13 +223,13 @@ class PHPMailer
 	var $error_count	 = 0;
 	var $LE			  = "\n";
 	/**#@-*/
-	
+
 	/////////////////////////////////////////////////
 	// VARIABLE METHODS
 	/////////////////////////////////////////////////
 
 	/**
-	 * Sets message type to HTML.  
+	 * Sets message type to HTML.
 	 * @param bool $bool
 	 * @return void
 	 */
@@ -265,7 +265,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Sets Mailer to send message using the qmail MTA. 
+	 * Sets Mailer to send message using the qmail MTA.
 	 * @return void
 	 */
 	function IsQmail() {
@@ -279,7 +279,7 @@ class PHPMailer
 	/////////////////////////////////////////////////
 
 	/**
-	 * Adds a "To" address.  
+	 * Adds a "To" address.
 	 * @param string $address
 	 * @param string $name
 	 * @return void
@@ -293,7 +293,7 @@ class PHPMailer
 	/**
 	 * Adds a "Cc" address. Note: this function works
 	 * with the SMTP mailer on win32, not with the "mail"
-	 * mailer.  
+	 * mailer.
 	 * @param string $address
 	 * @param string $name
 	 * @return void
@@ -307,7 +307,7 @@ class PHPMailer
 	/**
 	 * Adds a "Bcc" address. Note: this function works
 	 * with the SMTP mailer on win32, not with the "mail"
-	 * mailer.  
+	 * mailer.
 	 * @param string $address
 	 * @param string $name
 	 * @return void
@@ -319,7 +319,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Adds a "Reply-to" address.  
+	 * Adds a "Reply-to" address.
 	 * @param string $address
 	 * @param string $name
 	 * @return void
@@ -338,7 +338,7 @@ class PHPMailer
 	/**
 	 * Creates message and assigns Mailer. If the message is
 	 * not sent successfully then it returns false.  Use the ErrorInfo
-	 * variable to view description of the error.  
+	 * variable to view description of the error.
 	 * @return bool
 	 */
 	function Send() {
@@ -386,9 +386,9 @@ class PHPMailer
 
 		return true;
 	}
-	
+
 	/**
-	 * Sends mail using the $Sendmail program.  
+	 * Sends mail using the $Sendmail program.
 	 * @access private
 	 * @return bool
 	 */
@@ -406,7 +406,7 @@ class PHPMailer
 
 		fputs($mail, $header);
 		fputs($mail, $body);
-		
+
 		$result = pclose($mail) >> 8 & 0xFF;
 		if($result != 0)
 		{
@@ -418,7 +418,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Sends mail using the PHP mail() function.  
+	 * Sends mail using the PHP mail() function.
 	 * @access private
 	 * @return bool
 	 */
@@ -521,7 +521,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Initiates a connection to an SMTP server.  Returns false if the 
+	 * Initiates a connection to an SMTP server.  Returns false if the
 	 * operation failed.
 	 * @access private
 	 * @return bool
@@ -532,18 +532,14 @@ class PHPMailer
 		$this->smtp->do_debug = $this->SMTPDebug;
 		$hosts = explode(';', $this->Host);
 		$index = 0;
-		$connection = ($this->smtp->Connected()); 
+		$connection = ($this->smtp->Connected());
 
 		// Retry while there is no connection
 		while($index < count($hosts) && $connection == false)
 		{
-			if(strstr($hosts[$index], ':'))
-				list($host, $port) = explode(':', $hosts[$index]);
-			else
-			{
-				$host = $hosts[$index];
-				$port = $this->Port;
-			}
+			$server = parse_url($hosts[$index]);
+			$host = isset($server['scheme']) ? $server['scheme'].'://'.$server['host'] : $server['host'];
+			$port = isset($server['port']) ? $server['port'] : $this->Port;
 
 			if($this->smtp->Connect($host, $port, $this->Timeout))
 			{
@@ -551,10 +547,10 @@ class PHPMailer
 					$this->smtp->Hello($this->Helo);
 				else
 					$this->smtp->Hello($this->ServerHostname());
-		
+
 				if($this->SMTPAuth)
 				{
-					if(!$this->smtp->Authenticate($this->Username, 
+					if(!$this->smtp->Authenticate($this->Username,
 												  $this->Password))
 					{
 						$this->SetError($this->Lang('authenticate'));
@@ -588,7 +584,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Sets the language for all class error messages.  Returns false 
+	 * Sets the language for all class error messages.  Returns false
 	 * if it cannot load the language file.  The default language type
 	 * is English.
 	 * @param string $lang_type Type of language (e.g. Portuguese: "br")
@@ -607,7 +603,7 @@ class PHPMailer
 	/////////////////////////////////////////////////
 
 	/**
-	 * Creates recipient headers.  
+	 * Creates recipient headers.
 	 * @access private
 	 * @return string
 	 */
@@ -622,11 +618,11 @@ class PHPMailer
 		}
 		return $type.': '.implode(', ', $addr_str).$this->LE;
 	}
-	
+
 	/**
 	 * Wraps message for use with mailers that do not
 	 * automatically perform wrapping and for quoted-printable.
-	 * Original written by philippe.  
+	 * Original written by philippe.
 	 * @access private
 	 * @return string
 	 */
@@ -688,7 +684,7 @@ class PHPMailer
 			  else
 			  {
 				$buf_o = $buf;
-				$buf .= ($e == 0) ? $word : (' ' . $word); 
+				$buf .= ($e == 0) ? $word : (' ' . $word);
 
 				if (strlen($buf) > $length && $buf_o != '')
 				{
@@ -702,7 +698,7 @@ class PHPMailer
 
 		return $message;
 	}
-	
+
 	/**
 	 * Set the body wrapping.
 	 * @access private
@@ -711,7 +707,7 @@ class PHPMailer
 	function SetWordWrap() {
 		if($this->WordWrap < 1)
 			return;
-			
+
 		switch($this->message_type)
 		{
 		   case 'alt':
@@ -726,13 +722,13 @@ class PHPMailer
 	}
 
 	/**
-	 * Assembles message header.  
+	 * Assembles message header.
 	 * @access private
 	 * @return string
 	 */
 	function CreateHeader() {
 		$result = '';
-		
+
 		// Set the boundaries
 		$uniq_id = md5(uniqid(time()));
 		$this->boundary[1] = 'b1_' . $uniq_id;
@@ -743,7 +739,7 @@ class PHPMailer
 			$result .= $this->HeaderLine('Return-Path', trim($this->From));
 		else
 			$result .= $this->HeaderLine('Return-Path', trim($this->Sender));
-		
+
 		// To be created automatically by mail()
 		if($this->Mailer != 'mail')
 		{
@@ -758,7 +754,7 @@ class PHPMailer
 		$from = array();
 		$from[0][0] = trim($this->From);
 		$from[0][1] = $this->FromName;
-		$result .= $this->AddrAppend('From', $from); 
+		$result .= $this->AddrAppend('From', $from);
 		// sendmail and mail() extract Bcc from the header before sending
 		if((($this->Mailer == 'sendmail') || ($this->Mailer == 'mail')) && (count($this->bcc) > 0))
 			$result .= $this->AddrAppend('Bcc', $this->bcc);
@@ -775,17 +771,29 @@ class PHPMailer
 		//X-MSMail-Priority: Normal
 		//X-MimeOLE
 		$result .= $this->HeaderLine('X-Mailer', "PHPMailer [version " . $this->Version . "]");
-		
+
+		$ip = Security::get_ip();
+		$backtrace = debug_backtrace();
+		$src = 'unknown';
+		for ($i=0; $i<=count($backtrace); ++$i) {
+			if (isset($backtrace[$i]['function']) && 'send_mail' === $backtrace[$i]['function']) {
+			$src = str_replace(BASEDIR, '', $backtrace[$i]['file']);
+			$backtrace = NULL;
+			break;
+			}
+		}
+		$result .= $this->HeaderLine('X-DF-MailerSRC', $src . ' for ' . decode_ip($ip));
+
 		if($this->ConfirmReadingTo != '')
 		{
-			$result .= $this->HeaderLine('Disposition-Notification-To', 
+			$result .= $this->HeaderLine('Disposition-Notification-To',
 					   '<' . trim($this->ConfirmReadingTo) . '>');
 		}
 
 		// Add custom headers
 		for($index = 0; $index < count($this->CustomHeader); $index++)
 		{
-			$result .= $this->HeaderLine(trim($this->CustomHeader[$index][0]), 
+			$result .= $this->HeaderLine(trim($this->CustomHeader[$index][0]),
 					   $this->EncodeHeader(trim($this->CustomHeader[$index][1])));
 		}
 		$result .= $this->HeaderLine('MIME-Version', '1.0');
@@ -802,8 +810,8 @@ class PHPMailer
 			case 'alt_attachments':
 				if($this->InlineImageExists())
 				{
-					$result .= sprintf("Content-Type: %s;%s\ttype=\"text/html\";%s\tboundary=\"%s\"%s", 
-									"multipart/related", $this->LE, $this->LE, 
+					$result .= sprintf("Content-Type: %s;%s\ttype=\"text/html\";%s\tboundary=\"%s\"%s",
+									"multipart/related", $this->LE, $this->LE,
 									$this->boundary[1], $this->LE);
 				}
 				else
@@ -837,16 +845,16 @@ class PHPMailer
 		switch($this->message_type)
 		{
 			case 'alt':
-				$result .= $this->GetBoundary($this->boundary[1], '', 
+				$result .= $this->GetBoundary($this->boundary[1], '',
 											  'text/plain', '');
 				$result .= $this->EncodeString($this->AltBody, $this->Encoding);
 				$result .= $this->LE.$this->LE;
-				$result .= $this->GetBoundary($this->boundary[1], '', 
+				$result .= $this->GetBoundary($this->boundary[1], '',
 											  'text/html', '');
-				
+
 				$result .= $this->EncodeString($this->Body, $this->Encoding);
 				$result .= $this->LE.$this->LE;
-	
+
 				$result .= $this->EndBoundary($this->boundary[1]);
 				break;
 			case 'plain':
@@ -856,32 +864,32 @@ class PHPMailer
 				$result .= $this->GetBoundary($this->boundary[1], '', '', '');
 				$result .= $this->EncodeString($this->Body, $this->Encoding);
 				$result .= $this->LE;
-	 
+
 				$result .= $this->AttachAll();
 				break;
 			case 'alt_attachments':
 				$result .= sprintf('--%s%s', $this->boundary[1], $this->LE);
 				$result .= sprintf('Content-Type: %s;%s' .
 								   "\tboundary=\"%s\"%s",
-								   'multipart/alternative', $this->LE, 
+								   'multipart/alternative', $this->LE,
 								   $this->boundary[2], $this->LE.$this->LE);
-	
+
 				// Create text body
-				$result .= $this->GetBoundary($this->boundary[2], '', 
+				$result .= $this->GetBoundary($this->boundary[2], '',
 											  'text/plain', '') . $this->LE;
 
 				$result .= $this->EncodeString($this->AltBody, $this->Encoding);
 				$result .= $this->LE.$this->LE;
-	
+
 				// Create the HTML body
-				$result .= $this->GetBoundary($this->boundary[2], '', 
+				$result .= $this->GetBoundary($this->boundary[2], '',
 											  'text/html', '') . $this->LE;
-	
+
 				$result .= $this->EncodeString($this->Body, $this->Encoding);
 				$result .= $this->LE.$this->LE;
 
 				$result .= $this->EndBoundary($this->boundary[2]);
-				
+
 				$result .= $this->AttachAll();
 				break;
 		}
@@ -902,23 +910,23 @@ class PHPMailer
 		if($encoding == '') { $encoding = $this->Encoding; }
 
 		$result .= $this->TextLine('--' . $boundary);
-		$result .= sprintf('Content-Type: %s; charset = "%s"', 
+		$result .= sprintf('Content-Type: %s; charset="%s"',
 							$contentType, $charSet);
 		$result .= $this->LE;
 		$result .= $this->HeaderLine('Content-Transfer-Encoding', $encoding);
 		$result .= $this->LE;
-	   
+
 		return $result;
 	}
-	
+
 	/**
 	 * Returns the end of a message boundary.
 	 * @access private
 	 */
 	function EndBoundary($boundary) {
-		return $this->LE . '--' . $boundary . '--' . $this->LE; 
+		return $this->LE . '--' . $boundary . '--' . $this->LE;
 	}
-	
+
 	/**
 	 * Sets the message type.
 	 * @access private
@@ -970,7 +978,7 @@ class PHPMailer
 	 * @param string $type File extension (MIME) type.
 	 * @return bool
 	 */
-	function AddAttachment($path, $name = '', $encoding = 'base64', 
+	function AddAttachment($path, $name = '', $encoding = 'base64',
 						   $type = 'application/octet-stream') {
 		if(!is_file($path))
 		{
@@ -1021,7 +1029,7 @@ class PHPMailer
 			$type		= $this->attachment[$i][4];
 			$disposition = $this->attachment[$i][6];
 			$cid		 = $this->attachment[$i][7];
-			
+
 			$mime[] = sprintf('--%s%s', $this->boundary[1], $this->LE);
 			$mime[] = sprintf('Content-Type: %s; name="%s"%s', $type, $name, $this->LE);
 			$mime[] = sprintf('Content-Transfer-Encoding: %s%s', $encoding, $this->LE);
@@ -1029,7 +1037,7 @@ class PHPMailer
 			if($disposition == 'inline')
 				$mime[] = sprintf("Content-ID: <%s>%s", $cid, $this->LE);
 
-			$mime[] = sprintf('Content-Disposition: %s; filename="%s"%s', 
+			$mime[] = sprintf('Content-Disposition: %s; filename="%s"%s',
 							  $disposition, $name, $this->LE.$this->LE);
 
 			// Encode as string attachment
@@ -1041,7 +1049,7 @@ class PHPMailer
 			}
 			else
 			{
-				$mime[] = $this->EncodeFile($path, $encoding);				
+				$mime[] = $this->EncodeFile($path, $encoding);
 				if($this->IsError()) { return ''; }
 				$mime[] = $this->LE.$this->LE;
 			}
@@ -1051,7 +1059,7 @@ class PHPMailer
 
 		return join('', $mime);
 	}
-	
+
 	/**
 	 * Encodes attachment in requested format.  Returns an
 	 * empty string on failure.
@@ -1104,13 +1112,13 @@ class PHPMailer
 	}
 
 	/**
-	 * Encode a header string to best of Q, B, quoted or none.  
+	 * Encode a header string to best of Q, B, quoted or none.
 	 * @access private
 	 * @return string
 	 */
 	function EncodeHeader ($str, $position = 'text') {
 	  $x = 0;
-	  
+
 	  switch (strtolower($position)) {
 		case 'phrase':
 		  if (!preg_match('/[\200-\377]/', $str)) {
@@ -1151,12 +1159,12 @@ class PHPMailer
 
 	  $encoded = preg_replace('/^(.*)$/m', " =?".$this->CharSet."?$encoding?\\1?=", $encoded);
 	  $encoded = trim(str_replace("\n", $this->LE, $encoded));
-	  
+
 	  return $encoded;
 	}
-	
+
 	/**
-	 * Encode string to quoted-printable.  
+	 * Encode string to quoted-printable.
 	 * @access private
 	 * @return string
 	 */
@@ -1179,7 +1187,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Encode string to q encoding.  
+	 * Encode string to q encoding.
 	 * @access private
 	 * @return string
 	 */
@@ -1200,7 +1208,7 @@ class PHPMailer
 				  "'='.sprintf('%02X', ord('\\1'))", $encoded);
 			break;
 		}
-		
+
 		// Replace every spaces to _ (more readable than =20)
 		$encoded = str_replace(' ', '_', $encoded);
 
@@ -1217,7 +1225,7 @@ class PHPMailer
 	 * @param string $type File extension (MIME) type.
 	 * @return void
 	 */
-	function AddStringAttachment($string, $filename, $encoding = 'base64', 
+	function AddStringAttachment($string, $filename, $encoding = 'base64',
 								 $type = 'application/octet-stream') {
 		// Append to $attachment array
 		$cur = count($this->attachment);
@@ -1230,23 +1238,23 @@ class PHPMailer
 		$this->attachment[$cur][6] = 'attachment';
 		$this->attachment[$cur][7] = 0;
 	}
-	
+
 	/**
-	 * Adds an embedded attachment.  This can include images, sounds, and 
-	 * just about any other document.  Make sure to set the $type to an 
-	 * image type.  For JPEG images use "image/jpeg" and for GIF images 
+	 * Adds an embedded attachment.  This can include images, sounds, and
+	 * just about any other document.  Make sure to set the $type to an
+	 * image type.  For JPEG images use "image/jpeg" and for GIF images
 	 * use "image/gif".
 	 * @param string $path Path to the attachment.
-	 * @param string $cid Content ID of the attachment.  Use this to identify 
+	 * @param string $cid Content ID of the attachment.  Use this to identify
 	 *		the Id for accessing the image in an HTML form.
 	 * @param string $name Overrides the attachment name.
 	 * @param string $encoding File encoding (see $Encoding).
-	 * @param string $type File extension (MIME) type.  
+	 * @param string $type File extension (MIME) type.
 	 * @return bool
 	 */
-	function AddEmbeddedImage($path, $cid, $name = '', $encoding = 'base64', 
+	function AddEmbeddedImage($path, $cid, $name = '', $encoding = 'base64',
 							  $type = 'application/octet-stream') {
-	
+
 		if(!is_file($path))
 		{
 			$this->SetError($this->Lang('file_access') . $path);
@@ -1267,10 +1275,10 @@ class PHPMailer
 		$this->attachment[$cur][5] = false; // isStringAttachment
 		$this->attachment[$cur][6] = 'inline';
 		$this->attachment[$cur][7] = $cid;
-	
+
 		return true;
 	}
-	
+
 	/**
 	 * Returns true if an inline attachment is present.
 	 * @access private
@@ -1286,7 +1294,7 @@ class PHPMailer
 				break;
 			}
 		}
-		
+
 		return $result;
 	}
 
@@ -1378,7 +1386,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Returns the proper RFC 822 formatted date. 
+	 * Returns the proper RFC 822 formatted date.
 	 * @access private
 	 * @return string
 	 */
@@ -1393,8 +1401,8 @@ class PHPMailer
 	}
 
 	/**
-	 * Returns the appropriate server variable.  Should work with both 
-	 * PHP 4.1.0+ as well as older versions.  Returns an empty string 
+	 * Returns the appropriate server variable.  Should work with both
+	 * PHP 4.1.0+ as well as older versions.  Returns an empty string
 	 * if nothing is found.
 	 * @access private
 	 * @return mixed
@@ -1407,7 +1415,7 @@ class PHPMailer
 			if(!isset($_SERVER['REMOTE_ADDR']))
 				$_SERVER = $HTTP_ENV_VARS; // must be Apache
 		}
-		
+
 		if(isset($_SERVER[$varName]))
 			return $_SERVER[$varName];
 		else
@@ -1445,7 +1453,7 @@ class PHPMailer
 		else
 			return 'function Lang:Language string failed to load: ' . $key;
 	}
-	
+
 	/**
 	 * Returns true if an error occurred.
 	 * @return bool
@@ -1455,7 +1463,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Changes every end of line from CR or LF to CRLF.  
+	 * Changes every end of line from CR or LF to CRLF.
 	 * @access private
 	 * @return string
 	 */
@@ -1467,7 +1475,7 @@ class PHPMailer
 	}
 
 	/**
-	 * Adds a custom header. 
+	 * Adds a custom header.
 	 * @return void
 	 */
 	function AddCustomHeader($custom_header) {
