@@ -9,9 +9,9 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/includes/nbbcode.php,v $
-  $Revision: 9.46 $
+  $Revision: 9.46.2.6 $
   $Author: nanocaiordo $
-  $Date: 2008/01/31 08:52:47 $
+  $Date: 2012/01/21 07:53:08 $
 **********************************************/
 if (!defined('CPG_NUKE')) { exit; }
 
@@ -122,13 +122,13 @@ function smilies_table($mode, $field='message', $form='post')
 				if (!$col) {
 					$content .= '<tr align="center" valign="middle">';
 				}
-				$content .= "<td><a href=\"javascript:emoticon('".$form."', '".$field."', '".$data['code']."')\"><img src=\"" . $smilies_path . $smile_url . "\" style=\"border:0;\" alt=\"".$data['emoticon']."\" title=\"".$data['emoticon']."\" /></a></td>";
+				$content .= "<td><a href=\"javascript:emoticon('".$form."','".$field."','".$data['code']."')\"><img src=\"" . $smilies_path . $smile_url . "\" style=\"border:0;\" alt=\"".$data['emoticon']."\" title=\"".$data['emoticon']."\" /></a></td>";
 				$s_colspan = max($s_colspan, $col + 1);
 
 				if ($mode == 'onerow') {
 					if ($col >= 15) {
 						if ($num_smilies > 15) {
-							$content .= "<td colspan=\"$s_colspan\" class=\"nav\"><a href=\"$url\" onclick=\"window.open('$url', '_smilies', 'height=200,resizable=yes,scrollbars=yes,width=230');return false;\" target=\"_smilies\" class=\"nav\">$smilies_more</a></td>";
+							$content .= "<td colspan=\"$s_colspan\" class=\"nav\"><a href=\"$url\" onclick=\"window.open('$url', 'smilies', 'height=200,resizable=yes,scrollbars=yes,width=230');return false;\" target=\"smilies\" class=\"nav\">$smilies_more</a></td>";
 						}
 						break;
 					}
@@ -148,7 +148,7 @@ function smilies_table($mode, $field='message', $form='post')
 
 			if ($mode == 'inline' && $num_smilies > $inline_rows * $inline_cols) {
 				$content .= "<tr align=\"center\">
-					<td colspan=\"$s_colspan\" class=\"nav\"><a href=\"$url\" onclick=\"window.open('$url', '_smilies', 'height=200,resizable=yes,scrollbars=yes,width=230');return false;\" target=\"_smilies\" class=\"nav\">$smilies_more</a></td>
+					<td colspan=\"$s_colspan\" class=\"nav\"><a href=\"$url\" onclick=\"window.open('$url', 'smilies', 'height=200,resizable=yes,scrollbars=yes,width=230');return false;\" target=\"smilies\" class=\"nav\">$smilies_more</a></td>
 				</tr>";
 			}
 		}
@@ -294,7 +294,7 @@ function set_smilies($message, $url='') {
 		for ($i = 0; $i < count($smilies); $i++) {
 			$smilies[$i]['code'] = str_replace('#', '\#', preg_quote($smilies[$i]['code']));
 			$orig[] = "#([\s])".$smilies[$i]['code']."([\s<])#si";
-			$repl[] = '\\1<img src="' . $url . $smilies_path . $smilies[$i]['smile_url'] . '" alt="'.get_code_lang($smilies[$i]['emoticon'],$smilies_desc).'" title="'.get_code_lang($smilies[$i]['emoticon'],$smilies_desc).'" />\\2';
+			$repl[] = '\\1<img class="bbsmilies" src="' . $url . $smilies_path . $smilies[$i]['smile_url'] . '" alt="'.get_code_lang($smilies[$i]['emoticon'],$smilies_desc).'" title="'.get_code_lang($smilies[$i]['emoticon'],$smilies_desc).'" />\\2';
 		}
 	}
 	if (count($orig)) {
@@ -502,8 +502,8 @@ class BBCode {
 			$replacements[] = '<marquee direction="\\1" scrolldelay="60" scrollamount="1" onmouseover="this.stop()" onmouseout="this.start()">\\2</marquee>';
 
 			# [img]image_url_here[/img] code..
-			$patterns[] = "#\[img\]([\w]+(://|\.|/)[^ \?&=(\"\n\r\t<]*?)\[/img\]#si";
-			$replacements[] = "<img src=\"\\1\" style=\"border:0;\" alt=\"\" />";
+			$patterns[] = "#\[img\]([\w]+(://|\.|/)[^ \?%=&(\"\n\r\t<\\\]*?)\[/img\]#si";
+			$replacements[] = "<img src=\"\\1\" alt=\"\" />";
 
 			# [flash width= height= loop= ] and [/flash] code..
 			$patterns[] = "#\[flash width=([0-6]?[0-9]?[0-9]) height=([0-4]?[0-9]?[0-9])\]((ht|f)tp://)([^ \?&=\"\n\r\t<]*?(\.(swf|fla)))\[/flash\]#si";
@@ -524,13 +524,13 @@ class BBCode {
 		$text = preg_replace($patterns, $replacements, $text);
 
 		# Fix linebreaks on important items
-		$text = preg_replace("/<br>/si", "<br \/>", $text);
-		$text = preg_replace("/<ul><br \/>/si", "<ul>", $text);
-		$text = preg_replace("/<\/ul><br \/>/si", "</ul>", $text);
-		$text = preg_replace("/<\/ol><br \/>/si", "</ol>", $text);
-		$text = preg_replace("/<\/table><br \/>/si", "</table>", $text);
-		$text = preg_replace("/<\/div><br \/>/si", "</div>", $text);
-		$text = preg_replace("/<br \/><table/si", "<table", $text);
+		$text = preg_replace('#<br>#si', '<br />', $text);
+		$text = preg_replace('#<ul><br \/>#si', '<ul>', $text);
+		$text = preg_replace('#<\/ul><br \/>#si', '</ul>', $text);
+		$text = preg_replace('#<\/ol><br \/>#si', '</ol>', $text);
+		$text = preg_replace('#<\/table><br \/>#si', '</table>', $text);
+		$text = preg_replace('#<\/div><br \/>#si', '</div>', $text);
+		$text = preg_replace('#<br \/><table#si', '<table', $text);
 
 		# Remove our padding from the string..
 		return trim($text);
