@@ -6,7 +6,7 @@
  *	 copyright			  : (C) 2002 Meik Sievertsen
  *	 email				  : acyd.burn@gmx.de
  *
- *	 $Id: displaying.php,v 9.10 2007/09/13 06:21:38 nanocaiordo Exp $
+ *	 $Id: displaying.php,v 9.10.2.1 2009/06/03 15:44:33 phoenix Exp $
  *
  *
  ***************************************************************************/
@@ -179,7 +179,7 @@ function display_attachments_preview($attachment_list)
 	//atm just return
 	return;
 	
-	global $attach_config, $is_auth, $allowed_extensions, $lang, $userdata, $display_categories, $upload_dir, $upload_icons, $template, $db, $theme, $bgcolor2, $textcolor2;
+	global $attach_config, $is_auth, $allowed_extensions, $lang, $userdata, $display_categories, $upload_dir, $upload_icons, $template, $db, $bgcolor2, $textcolor2;
 	if (count($attachment_list) < 1) { return; }
 
 	init_display_template('preview', '{ATTACHMENTS}');
