@@ -8,10 +8,10 @@
 	Dragonfly is released under the terms and conditions
 	of the GNU GPL version 2 or any later version
 
-	$Source: /cvs/html/install/sql/data/core.php,v $
-	$Revision: 1.17 $
+	$Source: /cvs/html/install/sql/data/Attic/core.php,v $
+	$Revision: 1.17.2.3 $
 	$Author: nanocaiordo $
-	$Date: 2007/09/13 10:18:53 $
+	$Date: 2010/02/22 09:52:51 $
 **********************************************/
 if (!defined('INSTALL')) { exit; }
 
@@ -155,13 +155,13 @@ The e-mail address is used only for confirming your registration details and pas
 	'_security' => array(
 		'bots' => '1',
 		'email' => '1',
-		'ips' => '1',
+		'ips' => '0',
 		'referers' => '1',
-		'uas'  => '1',
-		'flooding' => '1',
-		'delay' => '1',
+		'uas'  => '0',
+		'flooding' => '0',
+		'delay' => '3',
 		'unban' => '1',
-		'bantime' => '86400',
+		'bantime' => '900',
 		'debug' => '0',
 		'shield' => '0'
 	),
@@ -411,6 +411,7 @@ $records['security_agents']['content'] = array(
 	'GoForIt' => array('GoForIt', 'GOFORITBOT', NULL, 'goforit.com/about/', 0, NULL),
 	'Gonzo' => array('Gonzo', 'gonzo1', '.t-ipconnect.de', 'telekom.de', 0, NULL),
 	'Google' => array('Google', 'Googlebot', 'crawl[0-9\\-]+.googlebot.com', 'google.com/bot.html', 0, NULL),
+	'Google-Sitemaps' => array('Google-Sitemaps', 'Google-Sitemaps/', NULL, NULL, 0, NULL),
 	'GoogleAds' => array('GoogleAds', 'Mediapartners-Google', NULL, NULL, 0, NULL),
 	'GoogleImg' => array('GoogleImg', 'Googlebot-Image', NULL, NULL, 0, NULL),
 	'GPU' => array('GPU', 'GPU p2p crawler', NULL, 'gpu.sourceforge.net/search_engine.php', 0, NULL),
