@@ -8,10 +8,10 @@
 	Dragonfly is released under the terms and conditions
 	of the GNU GPL version 2 or any later version
 
-	$Source: /cvs/html/install/sql/tables/core.php,v $
-	$Revision: 1.29 $
+	$Source: /cvs/html/install/sql/tables/Attic/core.php,v $
+	$Revision: 1.29.2.3 $
 	$Author: nanocaiordo $
-	$Date: 2007/08/19 09:13:43 $
+	$Date: 2010/07/05 08:49:34 $
 **********************************************/
 if (!defined('INSTALL')) { exit; }
 
@@ -30,7 +30,21 @@ $tables['admins'] = array(
 	'radminhistory' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
 	'radminnewsletter' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
 	'radminforums' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
-	'radmingroups' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0)
+	'radmingroups' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminmessages' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminblocks' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radmincache' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radmincpgmm' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radmindatabase' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminheadlines' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radmininfo' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminl10n' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminmodules' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminranks' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminreferers' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminsecurity' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminsettings' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'radminsmilies' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0)
 );
 // upgrade || new install
 if (isset($tablelist['cpg_installs']) || file_exists(BASEDIR.'install/sql/tables/coppermine.php')) {
@@ -272,7 +286,7 @@ $indexes['modules_links'] = array(
 );
 
 $tables['referer'] = array(
-	'url' => array('Type' => 'VARCHAR(100)', 'Null' => 0, 'Default' => ''),
+	'url' => array('Type' => 'VARCHAR(255)', 'Null' => 0, 'Default' => ''),
 	'lasttime' => array('Type' => DBFT_INT4, 'Null' => 0, 'Default' => 0),
 );
 $indexes['referer'] = array(
