@@ -8,10 +8,10 @@
 	Dragonfly is released under the terms and conditions
 	of the GNU GPL version 2 or any later version
 
-	$Source: /cvs/html/install/sql/tables/forums.php,v $
-	$Revision: 1.22 $
-	$Author: nanocaiordo $
-	$Date: 2007/08/19 09:13:43 $
+	$Source: /cvs/html/install/sql/tables/Attic/forums.php,v $
+	$Revision: 1.22.2.2 $
+	$Author: phoenix $
+	$Date: 2012/01/20 11:44:24 $
 **********************************************/
 if (!defined('INSTALL')) { exit; }
 
@@ -115,6 +115,18 @@ $indexes['bbcategories'] = array(
 		0 => array('name' => 'cat_order', 'Sub_part' => '', 'Null' => 0))
 );
 
+$table_ids['bbcloak'] = 'user_id';
+$tables['bbcloak'] = array(
+	'user_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'user_cloak' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0)
+);
+$indexes['bbcloak'] = array(
+	'PRIMARY' => array('unique' => 1, 'type' => 'BTREE',
+		0 => array('name' => 'user_id', 'Sub_part' => '', 'Null' => 0)),
+	'user_cloak' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'user_cloak', 'Sub_part' => '', 'Null' => 0))
+);
+
 $tables['bbconfig'] = array(
 	'config_name' => array('Type' => 'VARCHAR(255)', 'Null' => 0, 'Default' => ''),
 	'config_value' => array('Type' => 'VARCHAR(255)', 'Null' => 0, 'Default' => '')
@@ -172,6 +184,20 @@ $indexes['bbforbidden_extensions'] = array(
 		0 => array('name' => 'ext_id', 'Sub_part' => '', 'Null' => 0))
 );
 
+$table_ids['bbforum_archive'] = 'archive_id';
+$tables['bbforum_archive'] = array(
+	'archive_id' => array('Type' => 'SERIAL4', 'Null' => 0),
+	'forum_id' => array('Type' => DBFT_INT2, 'Null' => 0, 'Default' => 0),
+	'archive_days' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0),
+	'archive_freq' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0)
+);
+$indexes['bbforum_archive'] = array(
+	'PRIMARY' => array('unique' => 1, 'type' => 'BTREE',
+		0 => array('name' => 'archive_id', 'Sub_part' => '', 'Null' => 0)),
+	'forum_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'forum_id', 'Sub_part' => '', 'Null' => 0))
+);
+
 $table_ids['bbforum_prune'] = 'prune_id';
 $tables['bbforum_prune'] = array(
 	'prune_id' => array('Type' => 'SERIAL4', 'Null' => 0),
@@ -213,7 +239,11 @@ $tables['bbforums'] = array(
 	'auth_vote' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0),
 	'auth_pollcreate' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0),
 	'auth_attachments' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0),
-	'auth_download' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0)
+	'auth_download' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0),
+	'archive_next' => array('Type' => DBFT_INT4, 'Null' => 0, 'Default' => 0),
+	'archive_enable' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0),
+	'archive_topics' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'archive_posts' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0)
 );
 $indexes['bbforums'] = array(
 	'PRIMARY' => array('unique' => 1, 'type' => 'BTREE',
@@ -226,6 +256,33 @@ $indexes['bbforums'] = array(
 		0 => array('name' => 'forum_last_post_id', 'Sub_part' => '', 'Null' => 0))
 );
 
+$table_ids['bbforums_privileges'] = 'forum_id';
+$tables['bbforums_privileges'] = array(
+	'forum_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'user_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0)
+);
+$indexes['bbforums_privileges'] = array(
+	'forum_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'forum_id', 'Sub_part' => '', 'Null' => 0)),
+	'user_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'user_id', 'Sub_part' => '', 'Null' => 0))
+);
+
+$table_ids['bbforums_watch'] = 'forum_id';
+$tables['bbforums_watch'] = array(
+	'forum_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'user_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'notify_status' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0)
+);
+$indexes['bbforums_watch'] = array(
+	'forum_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'forum_id', 'Sub_part' => '', 'Null' => 0)),
+	'user_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'user_id', 'Sub_part' => '', 'Null' => 0)),
+	'notify_status' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'notify_status', 'Sub_part' => '', 'Null' => 0))
+);
+
 $table_ids['bbgroups'] = 'group_id';
 $tables['bbgroups'] = array(
 	'group_id' => array('Type' => 'SERIAL4', 'Null' => 0),
@@ -275,6 +332,39 @@ $indexes['bbposts'] = array(
 		1 => array('name' => 'topic_id', 'Sub_part' => '', 'Null' => 0))
 );
 
+$table_ids['bbposts_archive'] = 'post_id';
+$tables['bbposts_archive'] = array(
+	'post_id' => array('Type' => 'SERIAL4', 'Null' => 0),
+	'topic_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'forum_id' => array('Type' => DBFT_INT2, 'Null' => 0, 'Default' => 0),
+	'poster_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'post_time' => array('Type' => DBFT_INT4, 'Null' => 0, 'Default' => 0),
+	'poster_ip' => array('Type' => DBFT_VARBINARY.'(17)', 'Null' => 1),
+	'post_username' => array('Type' => 'VARCHAR(25)', 'Null' => 1, 'Default' => ''),
+	'enable_bbcode' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 1),
+	'enable_html' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
+	'enable_smilies' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 1),
+	'enable_sig' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 1),
+	'post_edit_time' => array('Type' => DBFT_INT4, 'Null' => 1, 'Default' => 0),
+	'post_edit_count' => array('Type' => DBFT_INT2, 'Null' => 0, 'Default' => 0),
+	'post_attachment' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0)
+);
+$indexes['bbposts_archive'] = array(
+	'PRIMARY' => array('unique' => 1, 'type' => 'BTREE',
+		0 => array('name' => 'post_id', 'Sub_part' => '', 'Null' => 0)),
+	'forum_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'forum_id', 'Sub_part' => '', 'Null' => 0)),
+	'topic_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'topic_id', 'Sub_part' => '', 'Null' => 0)),
+	'poster_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'poster_id', 'Sub_part' => '', 'Null' => 0)),
+	'post_time' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'post_time', 'Sub_part' => '', 'Null' => 0)),
+	'topic_n_id' => array('unique' => 0, 'type' => 'BTREE',
+		0 => array('name' => 'post_id', 'Sub_part' => '', 'Null' => 0),
+		1 => array('name' => 'topic_id', 'Sub_part' => '', 'Null' => 0))
+);
+
 $table_ids['bbposts_text'] = 'post_id';
 $tables['bbposts_text'] = array(
 	'post_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
@@ -286,6 +376,17 @@ $indexes['bbposts_text'] = array(
 		0 => array('name' => 'post_id', 'Sub_part' => '', 'Null' => 0))
 );
 
+$table_ids['bbposts_text_archive'] = 'post_id';
+$tables['bbposts_text_archive'] = array(
+	'post_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
+	'post_subject' => array('Type' => 'VARCHAR(255)', 'Null' => 1, 'Default' => ''),
+	'post_text' => array('Type' => 'TEXT', 'Null' => 1)
+);
+$indexes['bbposts_text_archive'] = array(
+	'PRIMARY' => array('unique' => 1, 'type' => 'BTREE',
+		0 => array('name' => 'post_id', 'Sub_part' => '', 'Null' => 0))
+);
+
 $table_ids['bbprivmsgs'] = 'privmsgs_id';
 $tables['bbprivmsgs'] = array(
 	'privmsgs_id' => array('Type' => 'SERIAL4', 'Null' => 0),
@@ -503,7 +604,9 @@ $tables['bbtopics'] = array(
 	'topic_first_post_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
 	'topic_moved_id' => array('Type' => DBFT_INT3, 'Null' => 0, 'Default' => 0),
 	'topic_attachment' => array('Type' => DBFT_BOOL, 'Null' => 0, 'Default' => 0),
-	'icon_id' => array('Type' => DBFT_INT4, 'Null' => 1, 'Default' => 0)
+	'icon_id' => array('Type' => DBFT_INT4, 'Null' => 1, 'Default' => 0),
+	'topic_archive_flag' => array('Type' => DBFT_INT1, 'Null' => 0, 'Default' => 0),
+	'topic_archive_id' => array('Type' => DBFT_INT3, 'Null' =>0, 'Default' => 0)
 );
 $indexes['bbtopics'] = array(
 	'PRIMARY' => array('unique' => 1, 'type' => 'BTREE',
