@@ -12,9 +12,9 @@
    (at your option) any later version.
   ********************************************
   $Source: /cvs/html/language/english/coppermine.php,v $
-  $Revision: 9.10 $
-  $Author: akamu $
-  $Date: 2006/03/02 00:08:29 $
+  $Revision: 9.10.8.2 $
+  $Author: nanocaiordo $
+  $Date: 2008/03/20 11:40:24 $
 Encoding test: n-array summation ∑ latin ae w/ acute ǽ
 *******************************************************/
 if (!defined('CPG_NUKE')) { exit; }
@@ -395,7 +395,7 @@ define('CAN_HAVE_GALLERY', 'Can have a personal gallery');
 //define('APPLY', 'Apply modifications');
 define('CREATE_NEW_GROUP', 'Create new group');
 define('DEL_GROUPS', 'Delete selected group(s)');
-define('CONFIRM_DEL', 'Warning, when you delete a group, users that belong to this group will be transfered to the \'Registered\' group !'."\n\n".'Do you want to proceed ?');
+define('CONFIRM_DEL', 'Warning, when you delete a group, users that belong to this group will be transfered to the \'Registered\' group !\\n\\nDo you want to proceed ?');
 define('GROUP_TITLE', 'Manage user groups');
 define('APPROVAL_1', 'Pub. Upl. approval (1)');
 define('APPROVAL_2', 'Priv. Upl. approval (2)');
