@@ -9,9 +9,9 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/language/english/forums.php,v $
-  $Revision: 9.9 $
+  $Revision: 9.9.8.2 $
   $Author: phoenix $
-  $Date: 2007/05/15 07:15:40 $
+  $Date: 2011/12/13 12:29:24 $
 
   If editing this file please edit the second 
   or right side of the pair of terms.
@@ -93,6 +93,7 @@ $lang = array(
     'You_last_visit' => 'You last visited on %s',
     'Current_time' => 'The time now is %s',
     'Search_new' => 'View posts since last visit',
+    'Search_last_24' => 'View posts last 24 hours',
     'Search_your_posts' => 'View your posts',
     'Search_unanswered' => 'View unanswered posts',
     'Register' => 'Register',
@@ -106,18 +107,31 @@ $lang = array(
     'Last_Post' => 'Last Post',
     'Moderator' => 'Moderator',
     'Moderators' => 'Moderators',
+    'no_moderators' => 'no moderators',
+    'Subforum' => 'Subforum',
+    'Subforums' => 'Subforums',
+    'Subforum_of' => 'Subforum of',
+    'Not_Subforum' => 'Not a Subforum',
     'No_new_posts_last_visit' => 'No new posts since your last visit.',
     'No_new_posts' => 'No new posts',
+    'No_new_sub_posts' => 'Subforum no new posts',
     'New_posts' => 'New posts',
+    'New_sub_posts' => 'Subforum new posts',
     'New_post' => 'New post',
     'No_new_posts_hot' => 'No new posts [Popular]',
     'New_posts_hot' => 'New posts [Popular]',
     'No_new_posts_locked' => 'No new posts [Locked]',
     'New_posts_locked' => 'New posts [Locked]',
     'Forum_is_locked' => 'Forum is locked',
+    'Subforum_is_locked' => 'Subforum is locked',
     'Login' => 'Log in',
     'Logout' => 'Log out',
     'Log_me_in' => 'Log me on automatically each visit',
+	'Admin_color' => 'Administrator Color',
+	'Moderator_color' => 'Moderator Color',
+	'Member_color' => 'Member Color',
+	'Allow_guest_captcha' => 'Captcha (security code) required for guests to post.',
+	'Allow_online_posts' => 'Display member online status in each post.',
     // Index page 
     'Index' => 'Index',
     'No_Posts' => 'No Posts',
@@ -125,8 +139,11 @@ $lang = array(
     'Private_Message' => 'Private Message',
     'Private_Messages' => 'Private Messages',
     'Who_is_Online' => 'Who is Online',
+    'Who_online_now' => 'Online now',
+    'Who_online_today' => 'Online today',
     'Mark_all_forums' => 'Mark all forums read',
     'Forums_marked_read' => 'All forums have been marked read',
+    'Total_posts_topics' => 'Our members have posted a total of %s posts in %s topics, and %s archived posts in %s archived topics.',
     // Viewforum 
     'View_forum' => 'View Forum',
     'Forum_not_exist' => 'The forum you selected does not exist.',
@@ -151,6 +168,11 @@ $lang = array(
     'Rules_vote_cannot' => 'You <b>cannot</b> vote in polls in this forum',
     'Rules_moderate' => 'You <b>can</b> %smoderate this forum%s',
     'No_topics_post_one' => 'There are no posts in this forum.<br />Click on the <b>Post New Topic</b> link on this page to post one.',
+    'Stop_watching_forum' => 'Stop watching this forum',
+    'Start_watching_forum' => 'Watch this forum for posts',
+    'No_longer_watching_forum' => 'You are no longer watching this forum',
+    'You_are_watching_forum' => 'You are now watching this forum',
+	'Forum_watch' => 'Forum Watch',
     // Viewtopic 
     'View_topic' => 'View topic',
     'Guest' => 'Guest',
@@ -186,11 +208,15 @@ $lang = array(
     'Move_topic' => 'Move this topic',
     'Delete_topic' => 'Delete this topic',
     'Split_topic' => 'Split this topic',
+	'New_topic_notify' => 'New Topic Notification',
     'Stop_watching_topic' => 'Stop watching this topic',
     'Start_watching_topic' => 'Watch this topic for replies',
     'No_longer_watching' => 'You are no longer watching this topic',
     'You_are_watching' => 'You are now watching this topic',
+	'Topic_watch' => 'Topic Watch',
     'Total_votes' => 'Total Votes',
+	'Online' => 'Online',
+	'Offline' => 'Offline',
     // Posting/Replying 
     'Message_body' => 'Message body',
     'Topic_review' => 'Topic review',
@@ -609,7 +635,7 @@ $lang = array(
 	  8 => '(GMT +8:00) Beijing, Hong Kong, Perth, Singapore, Taipei',
 	  9 => '(GMT +9:00) Osaka, Sapporo, Seoul, Tokyo, Yakutsk',
 	  '9.5' => '(GMT +9:30) Adelaide, Darwin',
-	  10 => '(GMT +10:00) Canberra, Guam, Melbourne, Sydney, Vladivostok',
+	  10 => '(GMT +10:00) Brisbane, Canberra, Guam, Melbourne, Sydney, Vladivostok',
       '10.5' => '(GMT +10:30) South Australia Summer', 
 	  11 => '(GMT +11:00) Magadan, New Caledonia, Solomon Islands',
       '11.5' => '(GMT +11:30) Norfolk Isl. Australia', 
@@ -731,7 +757,7 @@ $lang = array(
     'Attachbox_limit' => 'Your Attachbox is %d%% full',
     'No_quota_limit' => 'No Quota Limit',
     'Unlimited' => 'Unlimited',
-    // admin section 
+	# admin section 
     'General' => 'General Admin',
     'Users' => 'User Admin',
     'Groups' => 'Group Admin',
@@ -879,7 +905,7 @@ $lang = array(
     'No_banned_email' => 'No banned email addresses',
     'Ban_update_sucessful' => 'The banlist has been updated successfully',
     'Click_return_banadmin' => 'Click %sHere%s to return to Ban Control',
-    // Board Configuration 
+    # Board Configuration 
     'General_Config' => 'General Configuration',
     'Config_explain' => 'The form below will allow you to customize all the general board options. For User and Forum configurations use the related links on the left hand side.',
     'Click_return_config' => 'Click %sHere%s to return to General Configuration',
@@ -913,6 +939,13 @@ $lang = array(
     'Allow_sig' => 'Allow Signatures',
     'Max_sig_length' => 'Maximum signature length',
     'Max_sig_length_explain' => 'Maximum number of characters in user signatures',
+    'Allow_forum_watch' => 'Allow Forum Watch',
+	'Recycle_allow' => 'Allow Topic/Post Recycling',
+	'Recycle_forum' => 'Select a forum for recycled topics/posts<br />(beware the permissions you set)',
+	'Allow_online_index' => 'Display users currently online',
+	'Online_index_group' => 'Select group allowed to view users currently online',
+	'Allow_online_today' => 'Display users online for today',
+	'Online_today_group' => 'Select group allowed to view users online today',
     'Allow_name_change' => 'Allow Username changes',
     'COPPA_settings' => 'COPPA Settings',
     'COPPA_fax' => 'COPPA Fax Number',
@@ -1363,4 +1396,63 @@ $lang = array(
     'Auth_download' => 'Download Files',
     'Group_quota' => 'Group quota',
     'Topic_icons' => 'Topic icons',
-);
+
+	# Archive related language defines
+    'Archive' => 'Archiving',
+    'Enable_archive' => 'Enable Forum Archiving',
+    'Forum_archiving' => 'Auto-archiving',
+    'archive_freq' => 'Check for topic age every',
+    'archive_days' => 'Remove topics that have not been posted to in',
+    'Set_archive_data' => 'You have turned on auto-archive for this forum but did not set a frequency or number of days to archive. Please go back and do so.',
+    'Forum_Archive' => 'Forum Archive',
+    'Forum_Archive_explain' => 'This will archive any posts for topics which have not been posted to within the number of days you select. If you do not enter a number then all topics will be archived. It will not remove posts for topics in which polls are still running nor will it remove announcements or attachments. You will need to archive those topics manually.',
+    'Do_Archive' => 'Do Archive',
+    'Archive_topics_not_posted' => 'Archive topics with no replies in this many days',
+	'Topic_Archived' => 'Topic Archived',
+    'Topics_archived' => 'Topics archived',
+    'Posts_archived' => 'Posts archived',
+    'Archive_success' => 'Archiving of forums was successful',
+    'Topics_Archived' => 'The posts for the selected topics have been successfully archived.',
+	'Words_Removed' => 'Search Words Removed',
+	'Archive_topic' => 'Archive this topic',
+	'Revive_topic' => 'Revive this topic',
+    'Confirm_archive_topic' => 'Are you sure you want to archive the selected topic/s?',
+    'Revive_an_archived_topic' => 'Revive an archived topic',
+	'Click_to_revive' => 'Click to Revive Topic',
+	'Is_revived' => 'This Archived topic has been revived.',
+	'Revived_click_here' => 'Click here to view it.',
+    'Archive_Revive' => 'Archive Revive',
+    'Archive_Revive_Notes' => 'This is an archived topic - your reply will not be appended here.<br />Instead, a new topic will be generated in the active forum.<br />The new topic will provide a reference link to this archived topic.<br />',
+	'View_Archives' => 'View the Forum Archives',
+	'View_Active' => 'View the Active Forum',
+	'Archives' => 'Archives',
+	'Archived' => 'Archived',
+    'Cannot_edit_replied' => 'Sorry, but you may not edit posts that have been replied to.',
+	'Edit_last_post_only' => 'Restrict user edits, when allowed, to the last post.',
+
+	# Cloak language defines
+	'Allow_user_cloak' => 'Allow User Cloaking',
+	'Allow_user_cloak_explain' => 'If a user cloaks another user, then the cloakee\'s posts will not be displayed to the cloaker.',
+	'Cloak_users' => 'Cloak Users',
+	'Cloak_user' => 'Cloak user\'s posts',
+	'Cloak_user_stop' => 'Stop cloaking user\'s posts',
+	'Cloak_user_bypass' => 'display all cloaked posts',
+	'Post_cloaked' => 'Post cloaked',
+	'Cloaking_none_selected' => 'You did not select any users to stop cloaking',
+	'Cloaking_stopped' => 'Stopped cloaking users',
+	'Cloaking_stop' => 'Stop Cloaking',
+	'No_user_cloaked' => 'You are not cloaking any users',
+	'Allow_cloak_group' => 'Select group allowed to cloak other users',
+
+	# Privileges
+	'No_cigar' => 'Nice try, but no cigar - untouchable.',
+	'Another_User' => 'Another User',
+	'Privileges' => 'Privileges',
+	'User_Forum_Privileges' => 'User Forum Privileges',
+	'User_forum_explain' => 'Here you can remove posting privileges for an individual user, on a forum basis, or restore those same privileges at a later time.<br />The privileges affected are post, reply, edit, delete, create polls, vote, attach and download files.<br />Note: you cannot remove those privileges for designated administrators and moderators.',
+
+	# Restricted Group
+	'Restricted_group' => 'Restricted Group',
+	'Restricted_group_explain' => 'The chosen group loses privileges in all forums where authorization levels are set to REG.',
+
+);
\ No newline at end of file
