@@ -9,9 +9,9 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/language/english/main.php,v $
-  $Revision: 9.44 $
-  $Author: phoenix $
-  $Date: 2007/08/28 05:37:45 $
+  $Revision: 9.44.2.1 $
+  $Author: nanocaiordo $
+  $Date: 2011/10/06 14:06:58 $
 Encoding test: n-array summation ∑ latin ae w/ acute ǽ
 *******************************************************/
 if (!defined('CPG_NUKE')) { exit; }
@@ -30,7 +30,7 @@ define('_DATESTRING4','%1$s, %2$s %3$s');
 
 define('_NEXTPAGE','Next Page');
 define('_PREVIOUSPAGE','Previous Page');
-
+define('_LAST_ONLINE', 'Last Online');
 define('_TEXT_DIR','ltr');
 define('_ALIGN_TEXT','left');
 define('_SEARCH','Search');
