@@ -6,7 +6,7 @@
  *	copyright	  : (C) 2001 The phpBB Group
  *	email	  : support@phpbb.com
  *
- *	$Id: modcp.php,v 9.15 2007/10/18 14:38:23 phoenix Exp $
+ *	$Id: modcp.php,v 9.15.2.2 2011/12/13 12:29:27 phoenix Exp $
  *
  ***************************************************************************/
 
@@ -32,9 +32,7 @@ require_once('modules/'.$module_name.'/nukebb.php');
 require_once('includes/nbbcode.php');
 require_once('includes/phpBB/functions_admin.php');
 
-//
-// Obtain initial var settings
-//
+# Obtain initial var settings
 if (isset($_GET[POST_FORUM_URL]) || isset($_POST[POST_FORUM_URL])) {
 	$forum_id = (isset($_POST[POST_FORUM_URL])) ? intval($_POST[POST_FORUM_URL]) : intval($_GET[POST_FORUM_URL]);
 } else {
@@ -55,11 +53,10 @@ if (isset($_GET[POST_TOPIC_URL]) || isset($_POST[POST_TOPIC_URL])) {
 
 $confirm = (isset($_POST['confirm']) && $_POST['confirm']) ? TRUE : 0;
 
-//
-// Continue var definitions
-//
-$start = ( isset($_GET['start']) ) ? intval($_GET['start']) : 0;
+# Continue var definitions
+$start = isset($_POST['start']) ? intval($_POST['start']) : (isset($_GET['start']) ? intval($_GET['start']) : 0);
 
+$archive = ( isset($_POST['archive']) ) ? TRUE : FALSE;
 $delete = ( isset($_POST['delete']) ) ? TRUE : FALSE;
 $move = ( isset($_POST['move']) ) ? TRUE : FALSE;
 $lock = ( isset($_POST['lock']) ) ? TRUE : FALSE;
@@ -69,7 +66,9 @@ if ( isset($_POST['mode']) || isset($_GET['mode']) ) {
 	$mode = ( isset($_POST['mode']) ) ? $_POST['mode'] : $_GET['mode'];
 	$mode = htmlprepare($mode);
 } else {
-	if ( $delete ) {
+	if ( $archive ) {
+		$mode = 'archive';
+	} elseif ( $delete ) {
 		$mode = 'delete';
 	} else if ( $move ) {
 		$mode = 'move';
@@ -82,19 +81,20 @@ if ( isset($_POST['mode']) || isset($_GET['mode']) ) {
 	}
 }
 
-//
-// Obtain relevant data
-//
+# Obtain relevant data
 if ( !empty($topic_id) ) {
 	$result = $db->sql_query("SELECT f.forum_id, f.forum_name, f.forum_topics
 	  FROM ".TOPICS_TABLE." t, ".FORUMS_TABLE." f
-	  WHERE t.topic_id = ".$topic_id." AND f.forum_id = t.forum_id");
+	  WHERE t.topic_id = ".$topic_id." AND t.topic_archive_flag = 0 AND f.forum_id = t.forum_id");
 	$topic_row = $db->sql_fetchrow($result);
 	$forum_topics = ( $topic_row['forum_topics'] == 0 ) ? 1 : $topic_row['forum_topics'];
 	$forum_id = $topic_row['forum_id'];
 	$forum_name = $topic_row['forum_name'];
+	$recycle = ($board_config['allow_topic_recycle'] && $forum_id != $board_config['topic_recycle_forum']) ? true : false;
+	$mode = ($recycle && $mode == 'delete') ? $mode = 'recycle' : $mode;
 } else if ( !empty($forum_id) ) {
-	$result = $db->sql_query("SELECT forum_name, forum_topics FROM ".FORUMS_TABLE." WHERE forum_id = ".$forum_id);
+	$result = $db->sql_query("SELECT forum_name, forum_topics FROM ".FORUMS_TABLE." 
+	WHERE forum_id = ".$forum_id);
 	$topic_row = $db->sql_fetchrow($result);
 	$forum_topics = ( $topic_row['forum_topics'] == 0 ) ? 1 : $topic_row['forum_topics'];
 	$forum_name = $topic_row['forum_name'];
@@ -102,46 +102,152 @@ if ( !empty($topic_id) ) {
 	message_die(GENERAL_MESSAGE, 'Forum_not_exist');
 }
 
-//
-// Start session management
-//
+# Start session management
 $userdata = session_pagestart($user_ip, $forum_id);
 init_userprefs($userdata);
-//
-// End session management
-//
+# End session management
 
-//
-// Check if user did or did not confirm
-// If they did not, forward them to the last page they were on
-//
-if ( isset($_POST['cancel']) ) {
+# Check if user did or did not confirm
+# If they did not, forward them to the last page they were on
+if (isset($_POST['cancel'])) {
 	$redirect = '';
-	if ( $topic_id ) {
-		$redirect = "&file=viewtopic&".POST_TOPIC_URL."=$topic_id";
-	} else if ( $forum_id ) {
-		$redirect = "&file=viewforum&".POST_FORUM_URL."=$forum_id";
+	if ($topic_id) {
+		$redirect = '&amp;file=viewtopic&amp;'.POST_TOPIC_URL.'='.$topic_id;
+	} elseif ($forum_id && $archive) {
+		$redirect = '&amp;file=viewarchive&amp;'.POST_FORUM_URL.'='.$forum_id;
+	} elseif ($forum_id) {
+		$redirect = '&amp;file=viewforum&amp;'.POST_FORUM_URL.'='.$forum_id;
 	}
 	url_redirect(getlink($redirect));
 }
 
-//
-// Start auth check
-//
+# Start auth check
 $is_auth = auth(AUTH_ALL, $forum_id, $userdata);
 
 if (!$is_auth['auth_mod']) {
 	message_die(GENERAL_MESSAGE, $lang['Not_Moderator'], $lang['Not_Authorised']);
 }
-//
-// End Auth Check
-//
+# End Auth Check
 
-//
-// Do major work ...
-//
+# Do major work ...
 switch( $mode )
 {
+	case 'archive':
+		if (!$is_auth['auth_delete']) {
+			message_die(MESSAGE, sprintf($lang['Sorry_auth_delete'], $is_auth['auth_delete_type']));
+		}
+		$page_title = $lang['Mod_CP'];
+		require_once('includes/phpBB/page_header.php');
+		if ($confirm) {
+			require_once('includes/phpBB/functions_search.php');
+			$topics = isset($_POST['topic_id_list']) ? $_POST['topic_id_list'] : array($topic_id);
+			$topic_id_sql = '';
+			for ($i = 0; $i < count($topics); $i++) {
+				$topic_id_sql .= (($topic_id_sql != '') ? ', ' : '').intval($topics[$i]);
+			}
+			$result = $db->sql_query("SELECT topic_id FROM ".TOPICS_TABLE." 
+			WHERE topic_id IN ($topic_id_sql) AND forum_id = $forum_id");
+			$topic_id_sql = '';
+			while ($row = $db->sql_fetchrow($result)) {
+				$topic_id_sql .= (($topic_id_sql != '') ? ', ' : '').intval($row['topic_id']);
+			}
+			$db->sql_freeresult($result);
+
+			$result = $db->sql_query("SELECT poster_id, COUNT(post_id) AS posts FROM ".POSTS_TABLE." 
+			WHERE topic_id IN ($topic_id_sql) 
+			GROUP BY poster_id");
+			$count_sql = array();
+			while ($row = $db->sql_fetchrow($result)) {
+				$count_sql[] = "UPDATE ".USERS_TABLE." 
+				SET user_posts = user_posts - ".$row['posts']."
+				WHERE user_id = ".$row['poster_id'];
+			}
+			$db->sql_freeresult($result);
+			if (sizeof($count_sql)) {
+				for ($i = 0; $i < sizeof($count_sql); $i++) {
+					$db->sql_query($count_sql[$i]);
+				}
+			}
+
+			$result = $db->sql_query("SELECT post_id FROM ".POSTS_TABLE." 
+			WHERE topic_id IN ($topic_id_sql)");
+			$post_id_sql = '';
+			while ($row = $db->sql_fetchrow($result)) {
+				$post_id_sql .= (($post_id_sql != '') ? ', ' : '').intval($row['post_id']);
+				$db->sql_query("INSERT INTO ".POSTS_TABLE."_archive 
+				(post_id, topic_id, forum_id, poster_id, post_time, poster_ip, post_username, enable_bbcode, enable_html, enable_smilies, enable_sig, post_edit_time, post_edit_count, post_attachment) 
+				SELECT post_id, topic_id, forum_id, poster_id, post_time, poster_ip, post_username, enable_bbcode, enable_html, enable_smilies, enable_sig, post_edit_time, post_edit_count, post_attachment 
+				FROM ".POSTS_TABLE."
+				WHERE post_id='$row[post_id]'");
+				$db->sql_query("INSERT INTO ".POSTS_TEXT_TABLE."_archive 
+				(post_id, post_subject, post_text) 
+				SELECT post_id, post_subject, post_text 
+				FROM ".POSTS_TEXT_TABLE."
+				WHERE post_id='$row[post_id]'");
+			}
+			$db->sql_freeresult($result);
+
+			# Got all required info so go ahead and start deleting everything
+			if ($post_id_sql != '') {
+				$db->sql_query("UPDATE ".TOPICS_TABLE." 
+				SET topic_archive_flag='1' 
+				WHERE topic_id IN ($topic_id_sql)");
+				$archived_topics = $db->sql_affectedrows();
+				$db->sql_query("DELETE FROM ".POSTS_TABLE." 
+				WHERE post_id IN ($post_id_sql)");
+				$archived_posts = $db->sql_affectedrows();
+				$db->sql_query("DELETE FROM ".POSTS_TEXT_TABLE." 
+				WHERE post_id IN ($post_id_sql)");
+				$db->sql_query("UPDATE ".FORUMS_TABLE." 
+				SET archive_topics = archive_topics + $archived_topics, archive_posts = archive_posts + $archived_posts 
+				WHERE forum_id = $forum_id");
+
+				remove_search_post($post_id_sql);
+			}
+
+			$db->sql_query("DELETE FROM ".TOPICS_WATCH_TABLE." 
+			WHERE topic_id IN ($topic_id_sql)");
+
+			sync('forum', $forum_id);
+
+			if (!empty($topic_id)) {
+				$redirect_page = '&amp;file=viewforum&amp;'.POST_FORUM_URL.'='.$forum_id;
+				$l_redirect = sprintf($lang['Click_return_forum'], '<a href="'.getlink($redirect_page).'">', '</a>');
+			} else {
+				$redirect_page ='&amp;file=modcp&amp;'.POST_FORUM_URL."=$forum_id&amp;start=$start";
+				$l_redirect = sprintf($lang['Click_return_modcp'], '<a href="'.getlink($redirect_page).'">', '</a>');
+			}
+			url_refresh(getlink($redirect_page));
+			message_die(GENERAL_MESSAGE, $lang['Topics_Archived'].'<br /><br />'.$l_redirect);
+		} else {
+			# Not confirmed, show confirmation message
+			if (empty($_POST['topic_id_list']) && empty($topic_id)) {
+				message_die(GENERAL_MESSAGE, $lang['None_selected']);
+			}
+
+			$hidden_fields = '<input type="hidden" name="mode" value="'.$mode.'" /><input type="hidden" name="'.POST_FORUM_URL.'" value="'.$forum_id.'" />';
+
+			if (isset($_POST['topic_id_list'])) {
+				$topics = $_POST['topic_id_list'];
+				for ($i = 0; $i < count($topics); $i++) {
+					$hidden_fields .= '<input type="hidden" name="topic_id_list[]" value="'.intval($topics[$i]).'" />';
+				}
+			} else {
+				$hidden_fields .= '<input type="hidden" name="'.POST_TOPIC_URL.'" value="'.$topic_id.'" />';
+			}
+
+			$template->assign_vars(array(
+				'MESSAGE_TITLE' => $lang['Confirm'],
+				'MESSAGE_TEXT' => $lang['Confirm_archive_topic'],
+				'L_YES' => $lang['Yes'],
+				'L_NO' => $lang['No'],
+				'S_CONFIRM_ACTION' => getlink('&amp;file=modcp&amp;start='.$start),
+				'S_HIDDEN_FIELDS' => $hidden_fields)
+			);
+			$template->set_filenames(array('body' => 'confirm_body.html'));
+		}
+	break;
+
 	case 'delete':
 	  if (!$is_auth['auth_delete']) {
 		message_die(MESSAGE, sprintf($lang['Sorry_auth_delete'], $is_auth['auth_delete_type']));
@@ -155,8 +261,8 @@ switch( $mode )
 		for($i = 0; $i < count($topics); $i++) {
 		  $topic_id_sql .= ( ( $topic_id_sql != '' ) ? ', ' : '' ).intval($topics[$i]);
 		}
-		$result = $db->sql_query("SELECT topic_id FROM ".TOPICS_TABLE
-		 ." WHERE topic_id IN ($topic_id_sql) AND forum_id = $forum_id");
+		$result = $db->sql_query("SELECT topic_id FROM ".TOPICS_TABLE." 
+		WHERE topic_id IN ($topic_id_sql) AND forum_id = $forum_id");
 
 		$topic_id_sql = '';
 		while ($row = $db->sql_fetchrow($result)) {
@@ -164,12 +270,13 @@ switch( $mode )
 		}
 		$db->sql_freeresult($result);
 
-		$result = $db->sql_query("SELECT poster_id, COUNT(post_id) AS posts FROM ".POSTS_TABLE
-		 ." WHERE topic_id IN ($topic_id_sql) GROUP BY poster_id");
+		$result = $db->sql_query("SELECT poster_id, COUNT(post_id) AS posts FROM ".POSTS_TABLE." 
+		WHERE topic_id IN ($topic_id_sql) GROUP BY poster_id");
 
 		$count_sql = array();
 		while ( $row = $db->sql_fetchrow($result) ) {
-		  $count_sql[] = "UPDATE ".USERS_TABLE." SET user_posts = user_posts - ".$row['posts']."
+		  $count_sql[] = "UPDATE ".USERS_TABLE." 
+			SET user_posts = user_posts - ".$row['posts']."
 			WHERE user_id = ".$row['poster_id'];
 		}
 		$db->sql_freeresult($result);
@@ -179,50 +286,57 @@ switch( $mode )
 		  }
 		}
 
-		$result = $db->sql_query("SELECT post_id FROM ".POSTS_TABLE." WHERE topic_id IN ($topic_id_sql)");
+		$result = $db->sql_query("SELECT post_id FROM ".POSTS_TABLE." 
+		WHERE topic_id IN ($topic_id_sql)");
 		$post_id_sql = '';
 		while ( $row = $db->sql_fetchrow($result) ) {
 		  $post_id_sql .= ( ( $post_id_sql != '' ) ? ', ' : '' ).intval($row['post_id']);
 		}
 		$db->sql_freeresult($result);
 
-		$result = $db->sql_query("SELECT vote_id FROM ".VOTE_DESC_TABLE." WHERE topic_id IN ($topic_id_sql)");
+		$result = $db->sql_query("SELECT vote_id FROM ".VOTE_DESC_TABLE." 
+		WHERE topic_id IN ($topic_id_sql)");
 		$vote_id_sql = '';
 		while ( $row = $db->sql_fetchrow($result) ) {
 		  $vote_id_sql .= ( ( $vote_id_sql != '' ) ? ', ' : '' ).$row['vote_id'];
 		}
 		$db->sql_freeresult($result);
 
-		//
-		// Got all required info so go ahead and start deleting everything
-		//
-		$sql = "DELETE FROM ".TOPICS_TABLE." WHERE topic_id IN ($topic_id_sql) OR topic_moved_id IN ($topic_id_sql)";
+		# Got all required info so go ahead and start deleting everything
+		$sql = "DELETE FROM ".TOPICS_TABLE." 
+		WHERE topic_id IN ($topic_id_sql) OR topic_moved_id IN ($topic_id_sql)";
 		$db->sql_query($sql);
 		if ($post_id_sql != '') {
-		  $sql = "DELETE FROM ".POSTS_TABLE." WHERE post_id IN ($post_id_sql)";
-		  $db->sql_query($sql);
-		  $sql = "DELETE FROM ".POSTS_TEXT_TABLE." WHERE post_id IN ($post_id_sql)";
-		  $db->sql_query($sql);
-		  remove_search_post($post_id_sql);
-//		  if (defined('BBAttach_mod')) {
-		  delete_attachment(explode(', ', $post_id_sql));
+			$sql = "DELETE FROM ".POSTS_TABLE." 
+			WHERE post_id IN ($post_id_sql)";
+			$db->sql_query($sql);
+			$sql = "DELETE FROM ".POSTS_TEXT_TABLE." 
+			WHERE post_id IN ($post_id_sql)";
+			$db->sql_query($sql);
+			remove_search_post($post_id_sql);
+
+			delete_attachment(explode(', ', $post_id_sql));
 		}
 
 		if ($vote_id_sql != '') {
-		  $db->sql_query("DELETE FROM ".VOTE_DESC_TABLE." WHERE vote_id IN ($vote_id_sql)");
-		  $db->sql_query("DELETE FROM ".VOTE_RESULTS_TABLE." WHERE vote_id IN ($vote_id_sql)");
-		  $db->sql_query("DELETE FROM ".VOTE_USERS_TABLE." WHERE vote_id IN ($vote_id_sql)");
+			$db->sql_query("DELETE FROM ".VOTE_DESC_TABLE." 
+			WHERE vote_id IN ($vote_id_sql)");
+			$db->sql_query("DELETE FROM ".VOTE_RESULTS_TABLE." 
+			WHERE vote_id IN ($vote_id_sql)");
+			$db->sql_query("DELETE FROM ".VOTE_USERS_TABLE." 
+			WHERE vote_id IN ($vote_id_sql)");
 		}
 
-		$db->sql_query("DELETE FROM ".TOPICS_WATCH_TABLE." WHERE topic_id IN ($topic_id_sql)");
+		$db->sql_query("DELETE FROM ".TOPICS_WATCH_TABLE." 
+		WHERE topic_id IN ($topic_id_sql)");
 
 		sync('forum', $forum_id);
 
 		if (!empty($topic_id)) {
-		  $redirect_page = "&file=viewforum&".POST_FORUM_URL."=$forum_id";
+		  $redirect_page = "&amp;file=viewforum&amp;".POST_FORUM_URL."=$forum_id";
 		  $l_redirect = sprintf($lang['Click_return_forum'], '<a href="'.getlink($redirect_page).'">', '</a>');
 		} else {
-		  $redirect_page ="&file=modcp&".POST_FORUM_URL."=$forum_id";
+		  $redirect_page ="&amp;file=modcp&amp;".POST_FORUM_URL."=$forum_id&amp;start=$start";
 		  $l_redirect = sprintf($lang['Click_return_modcp'], '<a href="'.getlink($redirect_page).'">', '</a>');
 		}
 		url_refresh(getlink($redirect_page));
@@ -251,7 +365,7 @@ switch( $mode )
 		  'L_YES' => $lang['Yes'],
 		  'L_NO' => $lang['No'],
 
-		  'S_CONFIRM_ACTION' => getlink("&amp;file=modcp"),
+		  'S_CONFIRM_ACTION' => getlink("&amp;file=modcp&amp;start=".$start),
 		  'S_HIDDEN_FIELDS' => $hidden_fields)
 		);
 
@@ -259,6 +373,79 @@ switch( $mode )
 	  }
 	  break;
 
+	case 'recycle':
+		if (!$is_auth['auth_delete']) {
+			message_die(MESSAGE, sprintf($lang['Sorry_auth_delete'], $is_auth['auth_delete_type']));
+		}
+		$page_title = $lang['Mod_CP'];
+		require_once('includes/phpBB/page_header.php');
+		if ($confirm) {
+			if (empty($_POST['topic_id_list']) && empty($topic_id)) {
+				message_die(GENERAL_MESSAGE, $lang['None_selected']);
+			}
+			$new_forum_id = $board_config['topic_recycle_forum'];
+			$old_forum_id = $forum_id;
+			if ($new_forum_id != $old_forum_id) {
+				$topics = isset($_POST['topic_id_list']) ? $_POST['topic_id_list'] : array($topic_id);
+				$topic_list = '';
+				for ($i = 0; $i < count($topics); $i++) {
+					$topic_list .= (($topic_list != '') ? ', ' : '').intval($topics[$i]);
+				}
+				$sql = "SELECT * FROM ".TOPICS_TABLE."
+				WHERE topic_id IN ($topic_list) AND forum_id = $old_forum_id AND topic_status <> ".TOPIC_MOVED;
+				$result = $db->sql_query($sql);
+				$row = $db->sql_fetchrowset($result);
+				$db->sql_freeresult($result);
+				for ($i = 0; $i < count($row); $i++) {
+					$topic_id = $row[$i]['topic_id'];
+					$db->sql_query("UPDATE ".TOPICS_TABLE." 
+						SET forum_id = $new_forum_id 
+						WHERE topic_id = $topic_id");
+					$db->sql_query("UPDATE ".POSTS_TABLE." 
+						SET forum_id = $new_forum_id 
+						WHERE topic_id = $topic_id");
+				}
+				# Sync the forum indexes
+				sync('forum', $new_forum_id);
+				sync('forum', $old_forum_id);
+				$message = $lang['Topics_Removed'].'<br /><br />';
+			} else {
+				$message = $lang['None_Selected'].'<br /><br />';
+			}
+			if (!empty($topic_id)) {
+				$redirect_page = '&amp;file=viewforum&amp;'.POST_FORUM_URL.'='.$old_forum_id;
+				$message .= sprintf($lang['Click_return_forum'], '<a href="'.getlink($redirect_page).'">', '</a>');
+			} else {
+				$redirect_page = '&amp;file=modcp&amp;'.POST_FORUM_URL."=$forum_id&amp;start=$start";
+				$message .= sprintf($lang['Click_return_modcp'], '<a href="'.getlink($redirect_page).'">', '</a>');
+			}
+			url_refresh(getlink($redirect_page));
+			message_die(GENERAL_MESSAGE, $message);
+		} else {
+			if (empty($_POST['topic_id_list']) && empty($topic_id)) {
+				message_die(GENERAL_MESSAGE, $lang['None_selected']);
+			}
+			$hidden_fields = '<input type="hidden" name="mode" value="'.$mode.'" /><input type="hidden" name="'.POST_FORUM_URL.'" value="'.$forum_id.'" />';
+			if (isset($_POST['topic_id_list'])) {
+				$topics = $_POST['topic_id_list'];
+				for ($i = 0; $i < count($topics); $i++) {
+					$hidden_fields .= '<input type="hidden" name="topic_id_list[]" value="'.intval($topics[$i]).'" />';
+				}
+			} else {
+				$hidden_fields .= '<input type="hidden" name="'.POST_TOPIC_URL.'" value="'.$topic_id.'" />';
+			}
+			$template->assign_vars(array(
+				'MESSAGE_TITLE'		=> $lang['Confirm'],
+				'MESSAGE_TEXT'		=> $lang['Confirm_delete_topic'],
+				'L_YES'				=> $lang['Yes'],
+				'L_NO'				=> $lang['No'],
+				'S_CONFIRM_ACTION'	=> getlink('&amp;file=modcp&amp;start='.$start),
+				'S_HIDDEN_FIELDS'	=> $hidden_fields)
+			);
+			$template->set_filenames(array('body' => 'confirm_body.html'));
+		}
+	break;
+
 	case 'move':
 	  $page_title = $lang['Mod_CP'];
 	  require_once("includes/phpBB/page_header.php");
@@ -283,12 +470,18 @@ switch( $mode )
 			$topic_id = $row[$i]['topic_id'];
 			if ( isset($_POST['move_leave_shadow']) ) {
 				// Insert topic in the old forum that indicates that the forum has moved.
-				$sql = "INSERT INTO ".TOPICS_TABLE." (forum_id, topic_title, topic_poster, topic_time, topic_status, topic_type, topic_vote, topic_views, topic_replies, topic_first_post_id, topic_last_post_id, topic_moved_id)
-				  VALUES ($old_forum_id, '".Fix_Quotes($row[$i]['topic_title'])."', '".Fix_Quotes($row[$i]['topic_poster'])."', ".$row[$i]['topic_time'].", ".TOPIC_MOVED.", ".POST_NORMAL.", ".$row[$i]['topic_vote'].", ".$row[$i]['topic_views'].", ".$row[$i]['topic_replies'].", ".$row[$i]['topic_first_post_id'].", ".$row[$i]['topic_last_post_id'].", $topic_id)";
+				$sql = "INSERT INTO ".TOPICS_TABLE." 
+				(forum_id, topic_title, topic_poster, topic_time, topic_status, topic_type, topic_vote, topic_views, topic_replies, topic_first_post_id, topic_last_post_id, topic_moved_id)
+				VALUES 
+				($old_forum_id, '".Fix_Quotes($row[$i]['topic_title'])."', '".Fix_Quotes($row[$i]['topic_poster'])."', ".$row[$i]['topic_time'].", ".TOPIC_MOVED.", ".POST_NORMAL.", ".$row[$i]['topic_vote'].", ".$row[$i]['topic_views'].", ".$row[$i]['topic_replies'].", ".$row[$i]['topic_first_post_id'].", ".$row[$i]['topic_last_post_id'].", $topic_id)";
 				$db->sql_query($sql);
 			}
-			$db->sql_query("UPDATE ".TOPICS_TABLE." SET forum_id = $new_forum_id WHERE topic_id = $topic_id");
-			$db->sql_query("UPDATE ".POSTS_TABLE." SET forum_id = $new_forum_id WHERE topic_id = $topic_id");
+			$db->sql_query("UPDATE ".TOPICS_TABLE." 
+			SET forum_id = $new_forum_id 
+			WHERE topic_id = $topic_id");
+			$db->sql_query("UPDATE ".POSTS_TABLE." 
+			SET forum_id = $new_forum_id 
+			WHERE topic_id = $topic_id");
 		  }
 
 		  // Sync the forum indexes
@@ -299,10 +492,10 @@ switch( $mode )
 		  $message = $lang['No_Topics_Moved'].'<br /><br />';
 		}
 		if ( !empty($topic_id) ) {
-		  $redirect_page = "&file=viewtopic&".POST_TOPIC_URL."=$topic_id";
+		  $redirect_page = "&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id";
 		  $message .= sprintf($lang['Click_return_topic'], '<a href="'.getlink($redirect_page).'">', '</a>');
 		} else {
-		  $redirect_page = "&file=modcp&".POST_FORUM_URL."=$forum_id";
+		  $redirect_page = "&amp;file=modcp&amp;".POST_FORUM_URL."=$forum_id&amp;start=$start";
 		  $message .= sprintf($lang['Click_return_modcp'], '<a href="'.getlink($redirect_page).'">', '</a>');
 		}
 		$message = $message.'<br \><br \>'.sprintf($lang['Click_return_forum'], '<a href="'.getlink("&amp;file=viewforum&amp;".POST_FORUM_URL."=$old_forum_id").'">', '</a>');
@@ -325,12 +518,10 @@ switch( $mode )
 		$template->assign_vars(array(
 		  'MESSAGE_TITLE' => $lang['Confirm'],
 		  'MESSAGE_TEXT' => $lang['Confirm_move_topic'],
-
 		  'L_MOVE_TO_FORUM' => $lang['Move_to_forum'],
 		  'L_LEAVESHADOW' => $lang['Leave_shadow_topic'],
 		  'L_YES' => $lang['Yes'],
 		  'L_NO' => $lang['No'],
-
 		  'S_FORUM_SELECT' => make_forum_select('new_forum', $forum_id),
 		  'S_MODCP_ACTION' => getlink("&amp;file=modcp"),
 		  'S_HIDDEN_FIELDS' => $hidden_fields)
@@ -356,10 +547,10 @@ switch( $mode )
 		  AND topic_moved_id = 0";
 	  $result = $db->sql_query($sql);
 	  if ( !empty($topic_id) ) {
-		$redirect_page = '&file=viewtopic&'. POST_TOPIC_URL ."=$topic_id";
+		$redirect_page = '&amp;file=viewtopic&amp;'. POST_TOPIC_URL ."=$topic_id";
 		$message = sprintf($lang['Click_return_topic'], '<a href="'.getlink($redirect_page).'">', '</a>');
 	  } else {
-		$redirect_page = '&amp;file=modcp&amp;'.POST_FORUM_URL."=$forum_id";
+		$redirect_page = '&amp;file=modcp&amp;'.POST_FORUM_URL."=$forum_id&amp;start=$start";
 		$message = sprintf($lang['Click_return_modcp'], '<a href="'.getlink($redirect_page).'">', '</a>');
 	  }
 	  $message = $message.'<br \><br \>'.sprintf($lang['Click_return_forum'], '<a href="'.getlink('&amp;file=viewforum&amp;'.POST_FORUM_URL."=$forum_id").'">', '</a>');
@@ -383,10 +574,10 @@ switch( $mode )
 		  AND topic_moved_id = 0";
 	  $result = $db->sql_query($sql);
 	  if ( !empty($topic_id) ) {
-		$redirect_page = "&file=viewtopic&".POST_TOPIC_URL."=$topic_id";
+		$redirect_page = "&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id";
 		$message = sprintf($lang['Click_return_topic'], '<a href="'.getlink($redirect_page).'">', '</a>');
 	  } else {
-		$redirect_page = "&file=modcp&".POST_FORUM_URL."=$forum_id";
+		$redirect_page = "&amp;file=modcp&amp;".POST_FORUM_URL."=$forum_id&amp;start=$start";
 		$message = sprintf($lang['Click_return_modcp'], '<a href="'.getlink($redirect_page).'">', '</a>');
 	  }
 	  $message = $message.'<br \><br \>'.sprintf($lang['Click_return_forum'], '<a href="'.getlink("&amp;file=viewforum&amp;".POST_FORUM_URL."=$forum_id").'">', '</a>');
@@ -433,8 +624,10 @@ switch( $mode )
 		  }
 		  $new_forum_id = intval($_POST['new_forum_id']);
 		  $topic_time = gmtime();
-		  $sql	= "INSERT INTO ".TOPICS_TABLE." (topic_title, topic_poster, topic_time, forum_id, topic_status, topic_type)
-			VALUES ('".Fix_Quotes($post_subject)."', $first_poster, ".$topic_time.", $new_forum_id, ".TOPIC_UNLOCKED.", ".POST_NORMAL.")";
+		  $sql	= "INSERT INTO ".TOPICS_TABLE." 
+		  (topic_title, topic_poster, topic_time, forum_id, topic_status, topic_type)
+		  VALUES 
+		  ('".Fix_Quotes($post_subject)."', $first_poster, ".$topic_time.", $new_forum_id, ".TOPIC_UNLOCKED.", ".POST_NORMAL.")";
 		  $db->sql_query($sql);
 		  $new_topic_id = $db->sql_nextid('topic_id');
 
@@ -708,8 +901,11 @@ switch( $mode )
 			'L_REPLIES' => $lang['Replies'],
 			'L_LASTPOST' => $lang['Last_Post'],
 			'L_SELECT' => $lang['Select'],
+			'L_MARK_ALL' => $lang['Mark_all'],
+			'L_UNMARK_ALL' => $lang['Unmark_all'],
 
 			'U_VIEW_FORUM' => getlink("&amp;file=viewforum&amp;".POST_FORUM_URL."=$forum_id"),
+			'S_START'		=> $start,
 			'S_HIDDEN_FIELDS' => '<input type="hidden" name="'.POST_FORUM_URL.'" value="'.$forum_id.'" />',
 			'S_MODCP_ACTION' => getlink("&amp;file=modcp"))
 		);
@@ -806,4 +1002,4 @@ switch( $mode )
 	break;
 }
 
-require_once('includes/phpBB/page_tail.php');
+require_once('includes/phpBB/page_tail.php');
\ No newline at end of file
