@@ -6,7 +6,7 @@
  *	 copyright	: (C) 2001 The phpBB Group
  *	 email		: support@phpbb.com
  *
- *	 $Id: posting.php,v 9.20 2007/12/12 12:54:23 nanocaiordo Exp $
+ *	 $Id: posting.php,v 9.20.2.3 2012/01/21 07:53:11 nanocaiordo Exp $
  *
  *
  ***************************************************************************/
@@ -23,10 +23,22 @@ if (!defined('CPG_NUKE')) { exit; }
 require_once('modules/'.$module_name.'/nukebb.php');
 require_once('includes/nbbcode.php');
 require_once('includes/phpBB/functions_post.php');
+require_once('includes/nbbcode.php');
 
-//
-// Check and set various parameters
-//
+$attach_config['img_max_width_remote'] = 1;
+if ($attach_config['img_max_width_remote']) {
+	$modheader .= '
+<style type="text/css">.postbody img{max-width:'.$attach_config['img_link_width'].'px}
+<!--[if lt IE 8]>
+.postbody img {
+	width: expression(this.clientWidth > '.$attach_config['img_link_width'].' ? "'.$attach_config['img_link_width'].'px" : this.clientWidth+"px");
+}
+<![endif]-->
+</style>
+';
+}
+
+# Check and set various parameters
 $params = array('submit' => 'post', 'preview' => 'preview', 'delete' => 'delete', 'poll_delete' => 'poll_delete', 'poll_add' => 'add_poll_option', 'poll_edit' => 'edit_poll_option', 'mode' => 'mode');
 foreach ($params as $var => $param) {
 	$$var = (isset($_POST[$param]) ? htmlprepare($_POST[$param]) : (isset($_GET[$param]) ? htmlprepare($_GET[$param]) : ''));
@@ -40,49 +52,36 @@ foreach ($params as $var => $param) {
 
 $refresh = $preview || $poll_add || $poll_edit || $poll_delete;
 
-//
-// Set topic type
-//
+# Set topic type
 $topic_type = ( !empty($_POST['topictype']) ) ? intval($_POST['topictype']) : POST_NORMAL;
 
-//
-// If the mode is set to topic review then output
-// that review ...
-//
+# If the mode is set to topic review then output that review ...
 if ( $mode == 'topicreview' ) {
 	require_once('includes/phpBB/topic_review.php');
 	topic_review($topic_id, false);
 	exit;
 }
 
-//
-// Start session management
-//
+# Start session management
 $userdata = session_pagestart($user_ip, PAGE_POSTING);
 init_userprefs($userdata);
-//
-// End session management
-//
+# End session management
 
-//
-// Was cancel pressed? If so then redirect to the appropriate
-// page, no point in continuing with any further checks
-//
+# Was cancel pressed? If so then redirect to the appropriate
+# page, no point in continuing with any further checks
 if ( isset($_POST['cancel']) ) {
 	if ( $post_id ) {
-	url_redirect(getlink('&file=viewtopic&'.POST_POST_URL."=$post_id")."#$post_id");
+	url_redirect(getlink('&amp;file=viewtopic&amp;'.POST_POST_URL."=$post_id")."#$post_id");
 	} else if ( $topic_id ) {
-	url_redirect(getlink('&file=viewtopic&'.POST_TOPIC_URL."=$topic_id"));
+	url_redirect(getlink('&amp;file=viewtopic&amp;'.POST_TOPIC_URL."=$topic_id"));
 	} else if ( $forum_id ) {
-	url_redirect(getlink('&file=viewforum&'.POST_FORUM_URL."=$forum_id"));
+	url_redirect(getlink('&amp;file=viewforum&amp;'.POST_FORUM_URL."=$forum_id"));
 	} else {
 	url_redirect(getlink());
 	}
 }
 
-//
-// What auth type do we need to check?
-//
+# What auth type do we need to check?
 $is_auth = array();
 switch( $mode )
 {
@@ -117,10 +116,8 @@ switch( $mode )
 		break;
 }
 
-//
-// Here we do various lookups to find topic_id, forum_id, post_id etc.
-// Doing it here prevents spoofing (eg. faking forum_id, topic_id or post_id
-//
+# Here we do various lookups to find topic_id, forum_id, post_id etc.
+# Doing it here prevents spoofing (eg. faking forum_id, topic_id or post_id
 $error_msg = '';
 $post_data = array();
 switch ( $mode )
@@ -129,7 +126,8 @@ switch ( $mode )
 		if (empty($forum_id)) {
 			message_die(GENERAL_MESSAGE, $lang['Forum_not_exist']);
 		}
-		$sql = "SELECT * FROM ".FORUMS_TABLE." WHERE forum_id = $forum_id";
+		$sql = "SELECT * FROM ".FORUMS_TABLE." 
+		WHERE forum_id = $forum_id";
 		break;
 
 	case 'reply':
@@ -151,7 +149,7 @@ switch ( $mode )
 		$select_sql = ( !$submit ) ? ", t.topic_title, p.enable_bbcode, p.enable_html, p.enable_smilies, p.enable_sig, p.post_username, pt.post_subject, pt.post_text, u.username, u.user_id, u.user_sig" : '';
 		$from_sql = ( !$submit ) ? ", ".POSTS_TEXT_TABLE." pt, ".USERS_TABLE." u" : '';
 		$where_sql = ( !$submit ) ? "AND pt.post_id = p.post_id AND u.user_id = p.poster_id" : '';
-		$sql = "SELECT f.*, t.topic_id, t.topic_status, t.topic_type, t.topic_first_post_id, t.topic_last_post_id, t.topic_vote, p.post_id, p.poster_id, t.icon_id".$select_sql."
+		$sql = "SELECT f.*, t.topic_id, t.topic_status, t.topic_type, t.topic_first_post_id, t.topic_last_post_id, t.topic_vote, p.post_id, p.poster_id, p.post_time, t.icon_id".$select_sql."
 			FROM ".POSTS_TABLE." p, ".TOPICS_TABLE." t, ".FORUMS_TABLE." f".$from_sql."
 			WHERE p.post_id = $post_id
 				AND t.topic_id = p.topic_id
@@ -174,6 +172,11 @@ if ( $result = $db->sql_query($sql) )
 
 
 	$is_auth = auth(AUTH_ALL, $forum_id, $userdata, $post_info);
+	# Check forum posting privileges
+	$forum_privs = $db->sql_count($prefix.'_bbforums_privileges', "user_id='$userinfo[user_id]' AND forum_id='$forum_id'");
+	if ($forum_privs > 0 && !is_admin()) {
+		$is_auth['auth_post'] = $is_auth['auth_reply'] = $is_auth['auth_edit'] = $is_auth['auth_delete'] = $is_auth['auth_vote'] = $is_auth['auth_pollcreate'] = $is_auth['auth_attachments'] = $is_auth['auth_download'] = 0;
+	}
 
 	if ( $post_info['forum_status'] == FORUM_LOCKED && !$is_auth['auth_mod']) {
 	   message_die(GENERAL_MESSAGE, $lang['Forum_locked']);
@@ -188,9 +191,12 @@ if ( $result = $db->sql_query($sql) )
 		$post_data['last_post'] = ( $post_info['topic_last_post_id'] == $post_id ) ? true : false;
 		$post_data['last_topic'] = ( $post_info['forum_last_post_id'] == $post_id ) ? true : false;
 		$post_data['has_poll'] = ( $post_info['topic_vote'] ) ? true : false;
+		$post_data['post_subject'] = $post_info['post_subject'];
 		$post_data['topic_type'] = $post_info['topic_type'];
 		$post_data['poster_id'] = $post_info['poster_id'];
+		$post_data['post_time'] = $post_info['post_time'];
 		$post_data['icon_id'] = $post_info['icon_id'];
+		$post_data['topic_type'] = $post_info['topic_type'];
 		$poll_title = $poll_length = '';
 		if ( $post_data['first_post'] && $post_data['has_poll'] ) {
 			$sql = "SELECT *
@@ -217,13 +223,13 @@ if ( $result = $db->sql_query($sql) )
 			$post_data['edit_poll'] = ($post_data['first_post'] && $is_auth['auth_pollcreate']) ? true : false;
 		}
 
-		//
-		// Can this user edit/delete the post/poll?
-		//
+		# Can this user edit/delete the post/poll?
 		if ($post_info['poster_id'] != $userdata['user_id'] && !$is_auth['auth_mod']) {
 			$message = ($delete || $mode == 'delete') ? $lang['Delete_own_posts'] : $lang['Edit_own_posts'];
 			$message .= '<br /><br />'.sprintf($lang['Click_return_topic'], '<a href="'.getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id").'">', '</a>');
 			message_die(GENERAL_MESSAGE, $message);
+		} else if ( !$post_data['last_post'] && !$is_auth['auth_mod'] && $mode == 'editpost' && $board_config['edit_last_post_only']) {
+			message_die(GENERAL_MESSAGE, $lang['Cannot_edit_replied']);
 		} else if ( !$post_data['last_post'] && !$is_auth['auth_mod'] && ( $mode == 'delete' || $delete ) ) {
 			message_die(GENERAL_MESSAGE, $lang['Cannot_delete_replied']);
 		} else if ( !$post_data['edit_poll'] && !$is_auth['auth_mod'] && ( $mode == 'poll_delete' || $poll_delete ) ) {
@@ -235,15 +241,14 @@ if ( $result = $db->sql_query($sql) )
 		}
 		$post_data['first_post'] = ( $mode == 'newtopic' ) ? true : 0;
 		$post_data['last_post'] = $post_data['has_poll'] = $post_data['edit_poll'] = false;
+		$post_info['topic_title'] = ('newtopic' == $mode) ? (isset($_POST['subject']) ? $_POST['subject'] : '') : $post_info['topic_title'];
 	}
 } else {
 	message_die(GENERAL_MESSAGE, $lang['No_such_post']);
 }
 
-//
-// The user is not authed, if they're not logged in then redirect
-// them, else show them an error message
-//
+# The user is not authed, if they're not logged in then redirect
+# them, else show them an error message
 if (!$is_auth[$is_auth_type]) {
 	if (is_user()) {
 		message_die(GENERAL_MESSAGE, sprintf($lang['Sorry_'.$is_auth_type], $is_auth[$is_auth_type."_type"]));
@@ -251,9 +256,7 @@ if (!$is_auth[$is_auth_type]) {
 	url_redirect(getlink('Your_Account'), true);
 }
 
-//
-// Set toggles for various options
-//
+# Set toggles for various options
 if ( !$board_config['allow_html'] ) {
 	$html_on = 0;
 } else {
@@ -299,19 +302,13 @@ $template->assign_vars(array(
 	$attachment_mod['posting'] = new attach_posting();
 	$attachment_mod['posting']->posting_attachment_mod();
 
-// --------------------
-//	What shall we do?
-//
+#	What shall we do?
 if (($delete || $poll_delete || $mode == 'delete') && !$confirm) {
-	//
-	// Confirm deletion
-	//
+	# Confirm deletion
 	$s_hidden_fields = '<input type="hidden" name="'.POST_POST_URL.'" value="'.$post_id.'" />';
 	$s_hidden_fields .= ( $delete || $mode == "delete" ) ? '<input type="hidden" name="mode" value="delete" />' : '<input type="hidden" name="mode" value="poll_delete" />';
 	$l_confirm = ( $delete || $mode == 'delete' ) ? $lang['Confirm_delete'] : $lang['Confirm_delete_poll'];
-	//
-	// Output confirmation page
-	//
+	# Output confirmation page
 	require_once('includes/phpBB/page_header.php');
 	$template->assign_vars(array(
 		'MESSAGE_TITLE' => $lang['Information'],
@@ -326,9 +323,7 @@ if (($delete || $poll_delete || $mode == 'delete') && !$confirm) {
 	$template->set_filenames(array('body' => 'confirm_body.html'));
 	require_once('includes/phpBB/page_tail.php');
 } else if ($mode == 'vote') {
-	//
-	// Vote in a poll
-	//
+	# Vote in a poll
 	if (!empty($_POST['vote_id'])) {
 		$vote_option_id = intval($_POST['vote_id']);
 		$sql = 'SELECT vd.vote_id FROM '.VOTE_DESC_TABLE.' vd, '.VOTE_RESULTS_TABLE." vr
@@ -349,8 +344,10 @@ if (($delete || $poll_delete || $mode == 'delete') && !$confirm) {
 					WHERE vote_id = $vote_id
 						AND vote_option_id = $vote_option_id";
 				$db->sql_query($sql);
-				$sql = 'INSERT INTO '.VOTE_USERS_TABLE." (vote_id, vote_user_id, vote_user_ip)
-					VALUES ('$vote_id', ".$userdata['user_id'].", ".$userinfo['user_ip'].")";
+				$sql = 'INSERT INTO '.VOTE_USERS_TABLE." 
+					(vote_id, vote_user_id, vote_user_ip)
+					VALUES 
+					('$vote_id', ".$userdata['user_id'].", ".$userinfo['user_ip'].")";
 				$db->sql_query($sql);
 				$message = $lang['Vote_cast'];
 			} else {
@@ -363,26 +360,39 @@ if (($delete || $poll_delete || $mode == 'delete') && !$confirm) {
 		}
 		$db->sql_freeresult($result);
 
-		url_refresh(getlink("&file=viewtopic&".POST_TOPIC_URL."=$topic_id"));
-		$message .=	 '<br /><br />'.sprintf($lang['Click_view_message'], '<a href="'.getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id").'">', '</a>');
+		url_refresh(getlink('&amp;file=viewtopic&amp;'.POST_TOPIC_URL.'='.$topic_id));
+		$message .=	 '<br /><br />'.sprintf($lang['Click_view_message'], '<a href="'.getlink('&amp;file=viewtopic&amp;'.POST_TOPIC_URL.'='.$topic_id).'">', '</a>');
 		message_die(GENERAL_MESSAGE, $message);
 	} else {
-		url_redirect(getlink("&file=viewtopic&".POST_TOPIC_URL."=$topic_id", true));
+		url_redirect(getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id", true));
 	}
 } else if ($submit || $confirm) {
-	//
-	// Submit post/vote (newtopic, edit, reply, etc.)
-	//
+	# Submit post/vote (newtopic, edit, reply, etc.)
 	$return_message = $return_meta = '';
 
+	if ($mode == 'newtopic' || $mode == 'reply') {
+		if (!is_user() && !is_admin() && $board_config['allow_guest_captcha']) {
+			$gfxid = isset($_POST['gfxid']) ? $_POST['gfxid'] : 0;
+			$code = $CPG_SESS['gfx'][$gfxid];
+			$gfx_check  = isset($_POST['gfx_contact_check']) ? $_POST['gfx_contact_check'] : '';
+			if (strlen($gfx_check) < 2 || $code != $gfx_check) {
+				$sec_error = _SECURITYCODE.' incorrect<br /><br />'._GOBACK;
+			}
+			if (!empty($sec_error)) {
+				message_die(GENERAL_MESSAGE, $sec_error);
+			}
+		}
+	}
 	switch ($mode)
 	{
 		case 'editpost':
 		case 'newtopic':
 		case 'reply':
+			$archive_id = ( !empty($_POST['archive_id']) ) ? intval($_POST['archive_id']) : 0;
 			$topic_icon = ( !empty($_POST['topic_icon']) ) ? intval($_POST['topic_icon']) : 0;
 			$username = ( !empty($_POST['username']) ) ? $_POST['username'] : '';
 			$subject = ( !empty($_POST['subject']) ) ? $_POST['subject'] : '';
+			$subject = (!empty($archive_id)) ? '[revived] '.$subject : $subject;
 			$message = ( !empty($_POST['message']) ) ? $_POST['message'] : '';
 			if (isset($_POST['quick_quote']) && !empty($_POST['quick_quote'])) {
 				$message = $_POST['quick_quote'].$message;
@@ -395,7 +405,7 @@ if (($delete || $poll_delete || $mode == 'delete') && !$confirm) {
 
 			if ($error_msg == '') {
 				$topic_type = ($topic_type != $post_data['topic_type'] && !$is_auth['auth_sticky'] && !$is_auth['auth_announce']) ? $post_data['topic_type'] : $topic_type;
-				submit_post($mode, $post_data, $return_message, $return_meta, $forum_id, $topic_id, $post_id, $poll_id, $topic_type, $bbcode_on, $html_on, $smilies_on, $attach_sig, $username, $subject, $message, $poll_title, $poll_options, $poll_length, $topic_icon);
+				submit_post($mode, $post_data, $return_message, $return_meta, $forum_id, $topic_id, $post_id, $poll_id, $topic_type, $bbcode_on, $html_on, $smilies_on, $attach_sig, $username, $subject, $message, $poll_title, $poll_options, $poll_length, $topic_icon, $archive_id);
 			}
 			break;
 
@@ -410,10 +420,9 @@ if (($delete || $poll_delete || $mode == 'delete') && !$confirm) {
 			$user_id = ($mode == 'reply' || $mode == 'newtopic') ? $userdata['user_id'] : $post_data['poster_id'];
 			update_post_stats($mode, $post_data, $forum_id, $topic_id, $post_id, $user_id);
 		}
-//		if (defined('BBAttach_mod')) {
 			$attachment_mod['posting']->insert_attachment($post_id);
 		if ($error_msg == '' && $mode != 'poll_delete') {
-			user_notification($mode, $post_data, $post_info['topic_title'], $forum_id, $topic_id, $post_id, $notify_user);
+			user_notification($mode, $post_data, $post_info['topic_title'], $forum_id, $post_info['forum_name'], $topic_id, $post_id, $notify_user);
 		}
 		if ($mode == 'newtopic' || $mode == 'reply') {
 			$tracking_topics = isset($CPG_SESS[$module_name]['track_topics']) ? $CPG_SESS[$module_name]['track_topics'] : array();
@@ -471,9 +480,7 @@ if ($refresh || isset($_POST['del_poll_option']) || $error_msg != '')
 		$preview_subject = $subject;
 		$preview_username = $username;
 
-		//
-		// Finalise processing as per viewtopic
-		//
+		# Finalise processing as per viewtopic
 		if (!$html_on) {
 			if ($user_sig != '' || !$userdata['user_allowhtml']) {
 				$user_sig = BBCode::encode_html($user_sig);
@@ -510,7 +517,6 @@ if ($refresh || isset($_POST['del_poll_option']) || $error_msg != '')
 		}
 
 		$template->set_filenames(array('preview' => 'forums/posting_preview.html'));
-//		if (defined('BBAttach_mod')) {
 		$attachment_mod['posting']->preview_attachments();
 		$template->assign_vars(array(
 			'TOPIC_TITLE' => $preview_subject,
@@ -532,9 +538,7 @@ if ($refresh || isset($_POST['del_poll_option']) || $error_msg != '')
 	}
 	$message = htmlprepare($message);
 } else {
-	//
-	// User default entry point
-	//
+	# User default entry point
 	if ( $mode == 'newtopic' ) {
 		$user_sig = ($userdata['user_sig'] != '') ? $userdata['user_sig'] : '';
 		$username = (is_user()) ? $userdata['username'] : '';
@@ -542,13 +546,13 @@ if ($refresh || isset($_POST['del_poll_option']) || $error_msg != '')
 	} else if ( $mode == 'reply' ) {
 		$user_sig = ($userdata['user_sig'] != '') ? $userdata['user_sig'] : '';
 		$username = (is_user()) ? $userdata['username'] : '';
-		// begin Automatic Subject on Reply mod
+		# begin Automatic Subject on Reply mod
 		$subject = htmlunprepare($post_info['topic_title']);
 		if ( !preg_match('/^Re:/', $subject) && strlen($subject) > 0) {
 			$subject = substr('Re: '.$subject, 0, 60);
 		}
 		$subject = htmlprepare($subject);
-		// end Automatic Subject on Reply mod
+		# end Automatic Subject on Reply mod
 		$message = '';
 	} else if ( $mode == 'quote' || $mode == 'editpost' ) {
 		$subject = ( $post_data['first_post'] ) ? $post_info['topic_title'] : $post_info['post_subject'];
@@ -571,7 +575,7 @@ if ($refresh || isset($_POST['del_poll_option']) || $error_msg != '')
 			$replacement_word = array();
 			obtain_word_list($orig_word, $replace_word);
 			$msg_date = create_date($board_config['default_dateformat'], $postrow['post_time']);
-			// Use trim to get rid of spaces placed there by MS-SQL 2000
+			# Use trim to get rid of spaces placed there by MS-SQL 2000
 			$quote_username = ( trim($post_info['post_username']) != '' ) ? $post_info['post_username'] : $post_info['username'];
 			$message = '[quote="'.$quote_username.'"]'.$message.'[/quote]';
 			if ( !empty($orig_word) ) {
@@ -588,16 +592,12 @@ if ($refresh || isset($_POST['del_poll_option']) || $error_msg != '')
 	}
 }
 
-//
-// Signature toggle selection
-//
+# Signature toggle selection
 if( $user_sig != '' ) {
 	$template->assign_block_vars('switch_signature_checkbox', array());
 }
 
-//
-// HTML toggle selection
-//
+# HTML toggle selection
 if ( $board_config['allow_html'] ) {
 	$html_status = $lang['HTML_is_ON'];
 	$template->assign_block_vars('switch_html_checkbox', array());
@@ -605,9 +605,7 @@ if ( $board_config['allow_html'] ) {
 	$html_status = $lang['HTML_is_OFF'];
 }
 
-//
-// BBCode toggle selection
-//
+# BBCode toggle selection
 if ( $board_config['allow_bbcode'] ) {
 	$bbcode_status = $lang['BBCode_is_ON'];
 	$template->assign_block_vars('switch_bbcode_checkbox', array());
@@ -615,9 +613,7 @@ if ( $board_config['allow_bbcode'] ) {
 	$bbcode_status = $lang['BBCode_is_OFF'];
 }
 
-//
-// Smilies toggle selection
-//
+# Smilies toggle selection
 if ($board_config['allow_smilies']) {
 	$smilies_status = $lang['Smilies_are_ON'];
 	$template->assign_block_vars('switch_smilies_checkbox', array());
@@ -629,25 +625,19 @@ if (!is_user() || ($mode == 'editpost' && $post_info['poster_id'] == ANONYMOUS))
 	$template->assign_block_vars('switch_username_select', array());
 }
 
-//
-// Notify checkbox - only show if user is logged in
-//
+# Notify checkbox - only show if user is logged in
 if (is_user() && $is_auth['auth_read']) {
 	if ($mode != 'editpost' || ($mode == 'editpost' && $post_info['poster_id'] != ANONYMOUS)) {
 		$template->assign_block_vars('switch_notify_checkbox', array());
 	}
 }
 
-//
-// Delete selection
-//
+# Delete selection
 if ( $mode == 'editpost' && ( ( $is_auth['auth_delete'] && $post_data['last_post'] && ( !$post_data['has_poll'] || $post_data['edit_poll'] ) ) || $is_auth['auth_mod'] ) ) {
 	$template->assign_block_vars('switch_delete_checkbox', array());
 }
 
-//
-// Topic type selection
-//
+# Topic type selection
 $topic_type_toggle = '';
 if(!isset($post_data['topic_type'])) $post_data['topic_type'] = 0;
 if ( $mode == 'newtopic' || ( $mode == 'editpost' && $post_data['first_post'] ) ) {
@@ -691,9 +681,7 @@ switch( $mode )
 		break;
 }
 
-//
-// Include page header
-//
+# Include page header
 require_once('includes/phpBB/page_header.php');
 
 $template->set_filenames(array(
@@ -713,30 +701,28 @@ $template->assign_vars(array(
 	'U_VIEW_FORUM' => getlink("&amp;file=viewforum&amp;".POST_FORUM_URL."=$forum_id"))
 );
 
-//
-// This enables the forum/topic title to be output for posting
-// but not for privmsg (where it makes no sense)
-//
+# This enables the forum/topic title to be output for posting
+# but not for privmsg (where it makes no sense)
 $template->assign_block_vars('switch_not_privmsg', array());
 
-//get custom icons for this forum
+#get custom icons for this forum
 if ( !empty($forum_id)) $topic_icons = get_topic_icons($forum_id);
 
-//if this forum has icons
+#if this forum has icons
 $set_topic_icon = (!empty($topic_icons) && ($mode == 'newtopic' || ($mode == 'editpost' && $post_data['first_post'])) );
 if ($set_topic_icon)
 {
-	//if new topic, or we are editing the first post of a topic
+	#if new topic, or we are editing the first post of a topic
 	$icons_array = "var icons_array = new Array();icons_array[0]='images/spacer.gif';";
 	$topic_icon_post = isset($_POST['topic_icon']) ? intval($_POST['topic_icon']) : NULL;
 	while( list($key, $val) = each($topic_icons) ) {
 		$selected = '';
 		if (isset($topic_icon_post) && $val['icon_id'] == $topic_icon_post) {
-			//icon is set in post data EG preview. this must override all
-			//note: no icon is 0 in which case this will never pass
+			#icon is set in post data EG preview. this must override all
+			#note: no icon is 0 in which case this will never pass
 			$selected = 'selected';
 		} else if (isset($post_data['icon_id']) && $val['icon_id'] == $post_data['icon_id']) {
-			//this is the current icon for this thread (stored)
+			#this is the current icon for this thread (stored)
 			$selected = 'selected';
 		}
 		$template->assign_block_vars('topic_icon_option', array(
@@ -744,7 +730,7 @@ if ($set_topic_icon)
 			'S_ICON_NAME' => $val['icon_name'],
 			'S_SELECTED' => $selected)
 		);
-		//add this icons url to the javascript array
+		#add this icons url to the javascript array
 		$icons_array .= "icons_array[".$val['icon_id']."] = '".$val['icon_url']."';";
 	}
 	$template->assign_vars(array(
@@ -752,9 +738,7 @@ if ($set_topic_icon)
 	);
 }
 
-//
-// Output the data to the template
-//
+# Output the data to the template
 $template->assign_vars(array(
 	'USERNAME' => $username,
 	'SUBJECT' => $subject,
@@ -782,10 +766,13 @@ $template->assign_vars(array(
 	'L_DELETE_POST' => $lang['Delete_post'],
 	'L_EMPTY_MESSAGE' => $lang['Empty_message'],
 	'L_GO' => $lang['Go'],
+	'L_TYPESECCODE' => _TYPESECCODE,
 
 	'U_VIEWTOPIC' => ( $mode == 'reply' ) ? getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id&amp;postorder=desc") : '',
 	'U_REVIEW_TOPIC' => ( $mode == 'reply' ) ? getlink("&amp;file=posting&amp;mode=topicreview&amp;".POST_TOPIC_URL."=$topic_id&amp;popup=1") : '',
 
+	'S_GUEST_CAPTCHA' => !is_user() && !is_admin() && $board_config['allow_guest_captcha'] ? true : false,
+	'S_GFX_IMG' => generate_secimg(),
 	'S_HTML_CHECKED' => ( !$html_on ) ? 'checked="checked"' : '',
 	'S_BBCODE_CHECKED' => ( !$bbcode_on ) ? 'checked="checked"' : '',
 	'S_SMILIES_CHECKED' => ( !$smilies_on ) ? 'checked="checked"' : '',
@@ -799,9 +786,7 @@ $template->assign_vars(array(
 	)
 );
 
-//
-// Poll entry switch/output
-//
+# Poll entry switch/output
 if( ( $mode == 'newtopic' || ( $mode == 'editpost' && $post_data['edit_poll']) ) && $is_auth['auth_pollcreate'] )
 {
 	$template->assign_vars(array(
@@ -834,9 +819,7 @@ if( ( $mode == 'newtopic' || ( $mode == 'editpost' && $post_data['edit_poll']) )
 	$template->assign_var_from_handle('POLLBOX', 'pollbody');
 }
 
-//
-// Topic review
-//
+# Topic review
 if( $mode == 'reply' && $is_auth['auth_read'] ) {
 	require_once('includes/phpBB/topic_review.php');
 	topic_review($topic_id, true);
@@ -844,4 +827,4 @@ if( $mode == 'reply' && $is_auth['auth_read'] ) {
 	$template->assign_var_from_handle('TOPIC_REVIEW_BOX', 'reviewbody');
 }
 
-require_once('includes/phpBB/page_tail.php');
+require_once('includes/phpBB/page_tail.php');
\ No newline at end of file
