@@ -6,7 +6,7 @@
  *	 copyright		  : (C) 2001 The phpBB Group
  *	 email		  : support@phpbb.com
  *
- *	 $Id: search.php,v 9.14 2007/12/12 12:54:24 nanocaiordo Exp $
+ *	 $Id: search.php,v 9.14.2.2 2011/12/13 12:29:27 phoenix Exp $
  *
  *
  ***************************************************************************/
@@ -20,28 +20,18 @@
  *
  ***************************************************************************/
 if (!defined('CPG_NUKE')) { exit; }
-global $pagetitle,$module_name;
+global $pagetitle, $module_name;
 require_once('modules/'.$module_name.'/nukebb.php');
 require_once('includes/nbbcode.php');
 require_once('includes/phpBB/functions_search.php');
 
-//
-// Start session management
-//
+# Start session management
 $userdata = session_pagestart($user_ip, PAGE_SEARCH);
 init_userprefs($userdata);
-//
-// End session management
-//
+# End session management
 
-//
-// Define initial vars
-//
-if ( isset($_POST['mode']) || isset($_GET['mode']) ) {
-	$mode = ( isset($_POST['mode']) ) ? $_POST['mode'] : $_GET['mode'];
-} else {
-	$mode = '';
-}
+# Define initial vars
+$mode = isset($_POST['mode']) ? $_POST['mode'] : (isset($_GET['mode']) ? $_GET['mode'] : '');
 
 if ( isset($_POST['search_keywords']) || isset($_GET['search_keywords']) ) {
 	$search_keywords = ( isset($_POST['search_keywords']) ) ? $_POST['search_keywords'] : $_GET['search_keywords'];
@@ -56,8 +46,7 @@ if ( isset($_POST['search_author']) || isset($_GET['search_author'])) {
 }
 
 $search_id = ( isset($_GET['search_id']) ) ? $_GET['search_id'] : '';
-$show_results = ( isset($_POST['show_results']) ) ? $_POST['show_results'] : 'posts';
-$show_results = ($show_results == 'topics') ? 'topics' : 'posts';
+$show_results = isset($_POST['show_results']) ? $_POST['show_results'] : (isset($_GET['show_results']) ? $_GET['show_results'] : 'posts');
 
 if ( isset($_POST['search_terms']) ) {
 	$search_terms = ( $_POST['search_terms'] == 'all' ) ? 1 : 0;
@@ -96,18 +85,37 @@ $start = ( isset($_GET['start']) ) ? intval($_GET['start']) : 0;
 
 $sort_by_types = array($lang['Sort_Time'], $lang['Sort_Post_Subject'], $lang['Sort_Topic_Title'], $lang['Sort_Author'], $lang['Sort_Forum']);
 
-//
-// encoding match for workaround
-//
+# removing topics from the watchlist
+if ($mode == 'stopwatch' && is_user()) {
+	$topics = ( isset($_POST['topic_id_list']) ) ?	$_POST['topic_id_list'] : array($topic_id);
+	$topic_id_sql = '';
+	for($i = 0; $i < count($topics); $i++) {
+	  $topic_id_sql .= ( ( $topic_id_sql != '' ) ? ', ' : '' ).intval($topics[$i]);
+	}
+	$db->sql_query("DELETE FROM ".TOPICS_WATCH_TABLE." 
+	WHERE topic_id IN ($topic_id_sql)
+	AND user_id='$userdata[user_id]'");
+	url_redirect(getlink($module_name.'&amp;file=search&amp;search_id=watch&amp;start='.$start));
+}
+# removing forums from the watchlist
+if ($mode == 'stopwatchf' && is_user() && $board_config['allow_forum_watch']) {
+	$forums = ( isset($_POST['forum_id_list']) ) ?	$_POST['forum_id_list'] : array($forum_id);
+	$forum_id_sql = '';
+	for($i = 0; $i < count($forums); $i++) {
+	  $forum_id_sql .= ( ( $forum_id_sql != '' ) ? ', ' : '' ).intval($forums[$i]);
+	}
+	$db->sql_query("DELETE FROM ".FORUMS_WATCH_TABLE." 
+	WHERE forum_id IN ($forum_id_sql)
+	AND user_id='$userdata[user_id]'");
+	url_redirect(getlink($module_name.'&amp;file=search&amp;search_id=fwatch&amp;start='.$start));
+}
+
+# encoding match for workaround
 $multibyte_charset = 'big5, shift_jis, euc-kr, gb2312';
 
-//
-// Begin core code
-//
+# Begin core code
 if ( $mode == 'searchuser' ) {
-	//
-	// This handles the simple windowed user search functions called from various other scripts
-	//
+	# This handles the simple windowed user search functions called from various other scripts
 	if ( isset($_POST['search_username']) ) {
 		if (!eregi("\*", $_POST['search_username'])) $_POST['search_username'] = "*".$_POST['search_username']."*";
 		username_search($_POST['search_username']);
@@ -121,18 +129,61 @@ if ( $mode == 'searchuser' ) {
 	$split_search = array();
 	$total_match_count = 0;
 
-	//
-	// Search ID Limiter, decrease this value if you experience further timeout problems with searching forums
+	# Search ID Limiter, decrease this value if you experience further timeout problems with searching forums
 	$limiter = 5000;
 
-	//
-	// Cycle through options ...
-	//
-	if ( $search_id == 'newposts' || $search_id == 'egosearch' || $search_id == 'unanswered' || $search_keywords != '' || $search_author != '' ) {
-		if ( $search_id == 'newposts' || $search_id == 'egosearch' || ( $search_author != '' && $search_keywords == '' )  ) {
-			if ( $search_id == 'newposts' ) {
+	# Cycle through options ...
+	if ( $search_id == 'watch' || $search_id == 'fwatch' || $search_id == 'last40' || $search_id == 'last' || $search_id == 'newposts' || $search_id == 'egosearch' || $search_id == 'unanswered' || $search_keywords != '' || $search_author != '' ) {
+		if ( $search_id == 'watch' || $search_id == 'fwatch' || $search_id == 'last40' || $search_id == 'last' || $search_id == 'newposts' || $search_id == 'egosearch' || ( $search_author != '' && $search_keywords == '' )  ) {
+			if ( $search_id == 'last40' ) {
+				if (can_admin('forums')) {
+						$sql = "SELECT topic_id FROM ".POSTS_TABLE." 
+						GROUP BY topic_id 
+						ORDER BY post_time DESC 
+						LIMIT 40";
+				} else {
+					message_die(GENERAL_MESSAGE, 'Sorry, for administrators only.');
+				}
+				$last40 = true;
+				$show_results = 'topics';
+				$sort_by = 0;
+				$sort_dir = 'DESC';
+			} elseif ( $search_id == 'watch' ) {
 				if (is_user()) {
-					$sql = "SELECT post_id FROM " . POSTS_TABLE . " WHERE post_time >= " . $userdata['user_lastvisit'];
+					$sql = "SELECT topic_id FROM ".TOPICS_WATCH_TABLE." 
+					WHERE user_id = ".$userdata['user_id'];
+				} else {
+					url_redirect(getlink('Your_Account'), true);
+				}
+				$watch = true;
+				$show_results = 'topics';
+				$sort_by = 0;
+				$sort_dir = 'DESC';
+			} elseif ( $search_id == 'fwatch' && $board_config['allow_forum_watch']) {
+				if (is_user()) {
+					$sql = "SELECT forum_id FROM ".FORUMS_WATCH_TABLE." 
+					WHERE user_id = ".$userdata['user_id'];
+				} else {
+					url_redirect(getlink('Your_Account'), true);
+				}
+				$fwatch = true;
+				$show_results = 'forums';
+				$sort_by = 4;
+				$sort_dir = 'ASC';
+			} elseif ( $search_id == 'last' ) {
+				if (is_user()) {
+					$sql = "SELECT post_id FROM " . POSTS_TABLE . " 
+					WHERE post_time >= (".gmtime()." - 86400)";
+				} else {
+					url_redirect(getlink('Your_Account'), true);
+				}
+				$show_results = 'topics';
+				$sort_by = 0;
+				$sort_dir = 'DESC';
+			} else if ( $search_id == 'newposts' ) {
+				if (is_user()) {
+					$sql = "SELECT post_id FROM " . POSTS_TABLE . " 
+					WHERE post_time >= " . $userdata['user_lastvisit'];
 				} else {
 					url_redirect(getlink('Your_Account'), true);
 				}
@@ -141,7 +192,8 @@ if ( $mode == 'searchuser' ) {
 				$sort_dir = 'DESC';
 			} else if ( $search_id == 'egosearch' ) {
 				if (is_user()) {
-					$sql = "SELECT post_id FROM " . POSTS_TABLE . " WHERE poster_id = " . $userdata['user_id'];
+					$sql = "SELECT post_id FROM " . POSTS_TABLE . " 
+					WHERE poster_id = " . $userdata['user_id'];
 				} else {
 					url_redirect(getlink('Your_Account'), true);
 				}
@@ -182,8 +234,18 @@ if ( $mode == 'searchuser' ) {
 			}
 
 			$search_ids = array();
-			while( $row = $db->sql_fetchrow($result) ) {
-				$search_ids[] = $row['post_id'];
+			if ($search_id == 'watch' || isset($last40)) {
+				while( $row = $db->sql_fetchrow($result) ) {
+					$search_ids[] = $row['topic_id'];
+				}
+			} elseif ($search_id == 'fwatch') {
+				while( $row = $db->sql_fetchrow($result) ) {
+					$search_ids[] = $row['forum_id'];
+				}
+			} else {
+				while( $row = $db->sql_fetchrow($result) ) {
+					$search_ids[] = $row['post_id'];
+				}
 			}
 			$db->sql_freeresult($result);
 
@@ -281,12 +343,9 @@ if ( $mode == 'searchuser' ) {
 			$total_match_count = count($search_ids);
 		}
 
-		//
-		// If user is logged in then we'll check to see which (if any) private
-		// forums they are allowed to view and include them in the search.
-		//
-		// If not logged in we explicitly prevent searching of private forums
-		//
+		# If user is logged in then we'll check to see which (if any) private
+		# forums they are allowed to view and include them in the search.
+		# If not logged in we explicitly prevent searching of private forums
 		$auth_sql = '';
 		if ( $search_forum != -1 ) {
 			$is_auth = auth(AUTH_READ, $search_forum, $userdata);
@@ -312,9 +371,7 @@ if ( $mode == 'searchuser' ) {
 			}
 		}
 
-		//
-		// Author name search
-		//
+		# Author name search
 		if ( $search_author != '' ) {
 			if (preg_match('#^[\*%]+$#', trim($search_author)) || preg_match('#^[^\*]{1,2}$#', str_replace(array('*', '%'), '', trim($search_author)))) {
 				$search_author = '';
@@ -323,10 +380,8 @@ if ( $mode == 'searchuser' ) {
 		}
 
 		if ( $total_match_count ) {
-			if ( $show_results == 'topics' ) {
-				//
-				// This one is a beast, try to seperate it a bit (workaround for connection timeouts)
-				//
+			if ( $show_results == 'topics' || $show_results == 'forums') {
+				# This one is a beast, try to seperate it a bit (workaround for connection timeouts)
 				$search_id_chunks = array();
 				$count = 0;
 				$chunk = 0;
@@ -352,7 +407,28 @@ if ( $mode == 'searchuser' ) {
 						$where_sql .= ( $search_author == '' && $auth_sql == ''	 ) ? " AND post_time >= $search_time " : " AND p.post_time >= $search_time ";
 					}
 
-					if ( $search_author == '' && $auth_sql == '' ) {
+					if ( isset($last40) ) {
+						$from_sql = POSTS_TABLE . " p";
+						if ( $auth_sql != '' ) {
+							$from_sql .= ", " . USERS_TABLE . " u";
+							$from_sql .= ", " . FORUMS_TABLE . " f";
+							$where_sql .= " AND f.forum_id = p.forum_id AND $auth_sql";
+						}
+						$sql = "SELECT p.topic_id FROM  $from_sql
+							WHERE p.topic_id IN (" . implode(", ", $search_id_chunks[$i]) . ")
+							$where_sql
+							GROUP BY p.topic_id DESC LIMIT 50";
+					} elseif ( $search_id == 'watch' ) {
+						$sql = "SELECT topic_id FROM " . POSTS_TABLE . "
+							WHERE topic_id IN (" . implode(", ", $search_id_chunks[$i]) . ")
+							$where_sql
+							GROUP BY topic_id";
+					} elseif ( $search_id == 'fwatch' ) {
+						$sql = "SELECT forum_id FROM " . FORUMS_TABLE . "
+							WHERE forum_id IN (" . implode(", ", $search_id_chunks[$i]) . ")
+							$where_sql
+							GROUP BY forum_id";
+					} elseif ( $search_author == '' && $auth_sql == '' ) {
 						$sql = "SELECT topic_id FROM " . POSTS_TABLE . "
 							WHERE post_id IN (" . implode(", ", $search_id_chunks[$i]) . ")
 							$where_sql
@@ -379,7 +455,7 @@ if ( $mode == 'searchuser' ) {
 					}
 
 					while ($row = $db->sql_fetchrow($result)) {
-						$search_ids[] = $row['topic_id'];
+						$search_ids[] = $search_id == 'fwatch' ? $row['forum_id'] : $row['topic_id'];
 					}
 					$db->sql_freeresult($result);
 				}
@@ -460,9 +536,7 @@ if ( $mode == 'searchuser' ) {
 
 			$total_match_count = count($search_ids);
 
-			//
-			// Basic requirements
-			//
+			# Basic requirements
 			$show_results = 'topics';
 			$sort_by = 0;
 			$sort_dir = 'DESC';
@@ -470,22 +544,17 @@ if ( $mode == 'searchuser' ) {
 			message_die(GENERAL_MESSAGE, $lang['No_search_match']);
 		}
 
-		//
-		// Store new result data
-		//
+		# Store new result data
 		$search_results = implode(', ', $search_ids);
 		$per_page = ( $show_results == 'posts' ) ? $board_config['posts_per_page'] : $board_config['topics_per_page'];
 
-		//
-		// Combine both results and search data (apart from original query)
-		// so we can serialize it and place it in the DB
-		//
+		# Combine both results and search data (apart from original query)
+		# so we can serialize it and place it in the DB
 		$store_search_data = array();
 
-		//
-		// Limit the character length (and with this the results displayed at all following pages) to prevent
-		// truncated result arrays. Normally, search results above 12000 are affected.
-		// - to include or not to include
+		# Limit the character length (and with this the results displayed at all following pages) to prevent
+		# truncated result arrays. Normally, search results above 12000 are affected.
+		# - to include or not to include
 		/*
 		$max_result_length = 60000;
 		if (strlen($search_results) > $max_result_length)
@@ -513,9 +582,7 @@ if ( $mode == 'searchuser' ) {
 		}
 	}
 
-	//
-	// Look up data ...
-	//
+	# Look up data ...
 	if ( $search_results != '' ) {
 		if ( $show_results == 'posts' ) {
 			$sql = "SELECT pt.post_text, pt.post_subject, p.*, f.forum_id, f.forum_name, t.*, u.username, u.user_id, u.user_sig
@@ -525,6 +592,17 @@ if ( $mode == 'searchuser' ) {
 					AND f.forum_id = p.forum_id
 					AND p.topic_id = t.topic_id
 					AND p.poster_id = u.user_id";
+		} elseif ($show_results == 'forums') {
+			$sql = "SELECT t.*, f.forum_id, f.forum_name, u.username, u.user_id, u2.username as user2, u2.user_id as id2, p.post_username, p2.post_username AS post_username2, p2.post_time
+				FROM ".TOPICS_TABLE." t, ".FORUMS_TABLE." f, ".USERS_TABLE." u, ".POSTS_TABLE." p, ".POSTS_TABLE." p2, ".USERS_TABLE." u2
+				WHERE f.forum_id IN ($search_results)
+					AND f.forum_id = t.forum_id
+					AND t.topic_last_post_id = f.forum_last_post_id
+					AND t.topic_poster = u.user_id
+					AND p.post_id = f.forum_last_post_id
+					AND p2.post_id = f.forum_last_post_id
+					AND u2.user_id = p2.poster_id
+				";
 		} else {
 			$sql = "SELECT t.*, f.forum_id, f.forum_name, u.username, u.user_id, u2.username as user2, u2.user_id as id2, p.post_username, p2.post_username AS post_username2, p2.post_time
 				FROM " . TOPICS_TABLE . " t, " . FORUMS_TABLE . " f, " . USERS_TABLE . " u, " . POSTS_TABLE . " p, " . POSTS_TABLE . " p2, " . USERS_TABLE . " u2
@@ -533,12 +611,13 @@ if ( $mode == 'searchuser' ) {
 					AND f.forum_id = t.forum_id
 					AND p.post_id = t.topic_first_post_id
 					AND p2.post_id = t.topic_last_post_id
-					AND u2.user_id = p2.poster_id";
+					AND u2.user_id = p2.poster_id
+				";
 		}
 
 		$per_page = ( $show_results == 'posts' ) ? $board_config['posts_per_page'] : $board_config['topics_per_page'];
 
-		$sql .= " ORDER BY ";
+		$sql .= ' ORDER BY ';
 		switch ( $sort_by )
 		{
 			case 1:
@@ -551,7 +630,7 @@ if ( $mode == 'searchuser' ) {
 				$sql .= 'u.username';
 				break;
 			case 4:
-				$sql .= 'f.forum_id';
+				$sql .= 't.topic_last_post_id DESC, f.forum_id';
 				break;
 			default:
 				$sql .= ( $show_results == 'posts' ) ? 'p.post_time' : 'p2.post_time';
@@ -570,18 +649,14 @@ if ( $mode == 'searchuser' ) {
 
 		$db->sql_freeresult($result);
 
-		//
-		// Define censored word matches
-		//
+		# Define censored word matches
 		$orig_word = array();
 		$replacement_word = array();
 		obtain_word_list($orig_word, $replacement_word);
 
-		//
-		// Output header
-		//
+		# Output header
 		$page_title = $lang['Search'];
-		require_once("includes/phpBB/page_header.php");
+		require_once('includes/phpBB/page_header.php');
 
 		make_jumpbox('viewforum');
 
@@ -618,10 +693,10 @@ if ( $mode == 'searchuser' ) {
 		$tracking_forums = isset($CPG_SESS[$module_name]['track_forums']) ? $CPG_SESS[$module_name]['track_forums'] : array();
 
 		for($i = 0; $i < count($searchset); $i++) {
-			$forum_url = getlink("&amp;file=viewforum&amp;" . POST_FORUM_URL . '=' . $searchset[$i]['forum_id']);
-			$topic_url = getlink("&amp;file=viewtopic&amp;" . POST_TOPIC_URL . '=' . $searchset[$i]['topic_id'] . (!empty($highlight_active) ? "&amp;highlight=$highlight_active" : ""));
+			$forum_url = getlink('&amp;file=viewforum&amp;' . POST_FORUM_URL . '=' . $searchset[$i]['forum_id']);
+			$topic_url = getlink('&amp;file=viewtopic&amp;' . POST_TOPIC_URL . '=' . $searchset[$i]['topic_id'] . (!empty($highlight_active) ? "&amp;highlight=$highlight_active" : ""));
 			if (isset($searchset[$i]['post_id'])) {
-				$post_url = getlink("&amp;file=viewtopic&amp;" . POST_POST_URL . '=' . $searchset[$i]['post_id'] . (!empty($highlight_active) ? "&amp;highlight=$highlight_active" : "")) . '#' . $searchset[$i]['post_id'];
+				$post_url = getlink('&amp;file=viewtopic&amp;' . POST_POST_URL . '=' . $searchset[$i]['post_id'] . (!empty($highlight_active) ? "&amp;highlight=$highlight_active" : "")) . '#' . $searchset[$i]['post_id'];
 			} else {
 				$post_url = '';
 			}
@@ -635,10 +710,8 @@ if ( $mode == 'searchuser' ) {
 
 			if ($show_results == 'posts') {
 				if (isset($return_chars)) {
-					//
-					// If the board has HTML off but the post has HTML
-					// on then we process it, else leave it alone
-					//
+					# If the board has HTML off but the post has HTML
+					# on then we process it, else leave it alone
 					if ($return_chars != -1) {
 						$message = strip_tags($message);
 						$message = preg_replace('/\[url\]|\[\/url\]/si', '', $message);
@@ -751,7 +824,7 @@ if ( $mode == 'searchuser' ) {
 
 				}
 
-				$poster = ( $searchset[$i]['user_id'] != ANONYMOUS ) ? '<a href="' . getlink("Your_Account&amp;profile=" . $searchset[$i]['user_id']) . '">' : '';
+				$poster = ( $searchset[$i]['user_id'] != ANONYMOUS ) ? '<a href="' . getlink('Your_Account&amp;profile=' . $searchset[$i]['user_id']) . '">' : '';
 				$poster .= ( $searchset[$i]['user_id'] != ANONYMOUS ) ? $searchset[$i]['username'] : ( ( $searchset[$i]['post_username'] != "" ) ? $searchset[$i]['post_username'] : $lang['Guest'] );
 				$poster .= ( $searchset[$i]['user_id'] != ANONYMOUS ) ? '</a>' : '';
 
@@ -829,7 +902,7 @@ if ( $mode == 'searchuser' ) {
 					$times = 1;
 					for($j = 0; $j < $replies + 1; $j += $board_config['posts_per_page'])
 					{
-						$goto_page .= '<a href="' . getlink("&amp;file=viewtopic&amp;" . POST_TOPIC_URL . "=" . $topic_id . "&amp;start=$j") . '">' . $times . '</a>';
+						$goto_page .= '<a href="' . getlink('&amp;file=viewtopic&amp;' . POST_TOPIC_URL . '=' . $topic_id . "&amp;start=$j") . '">' . $times . '</a>';
 						if ( $times == 1 && $total_pages > 4 )
 						{
 							$goto_page .= ' ... ';
@@ -906,7 +979,7 @@ if ( $mode == 'searchuser' ) {
 								if ($unread_topics) {
 									$folder_image = $folder_new;
 									$folder_alt = $lang['New_posts'];
-									$newest_post_img = '<a href="' . getlink("&amp;file=viewtopic&amp;" . POST_TOPIC_URL . "=$topic_id&amp;view=newest") . '"><img src="' . $images['icon_newest_reply'] . '" alt="' . $lang['View_newest_post'] . '" title="' . $lang['View_newest_post'] . '" /></a> ';
+									$newest_post_img = '<a href="' . getlink('&amp;file=viewtopic&amp;' . POST_TOPIC_URL . "=$topic_id&amp;view=newest") . '"><img src="' . $images['icon_newest_reply'] . '" alt="' . $lang['View_newest_post'] . '" title="' . $lang['View_newest_post'] . '" /></a> ';
 								} else {
 									$folder_alt = ( $searchset[$i]['topic_status'] == TOPIC_LOCKED ) ? $lang['Topic_locked'] : $lang['No_new_posts'];
 									$folder_image = $folder;
@@ -918,7 +991,7 @@ if ( $mode == 'searchuser' ) {
 							else if ($searchset[$i]['post_time'] > $userdata['user_lastvisit']) {
 								$folder_image = $folder_new;
 								$folder_alt = $lang['New_posts'];
-								$newest_post_img = '<a href="' . getlink("&amp;file=viewtopic&amp;" . POST_TOPIC_URL . "=$topic_id&amp;view=newest") . '"><img src="' . $images['icon_newest_reply'] . '" alt="' . $lang['View_newest_post'] . '" title="' . $lang['View_newest_post'] . '" /></a> ';
+								$newest_post_img = '<a href="' . getlink('&amp;file=viewtopic&amp;' . POST_TOPIC_URL . "=$topic_id&amp;view=newest") . '"><img src="' . $images['icon_newest_reply'] . '" alt="' . $lang['View_newest_post'] . '" title="' . $lang['View_newest_post'] . '" /></a> ';
 							} else {
 								$folder_image = $folder;
 								$folder_alt = ( $searchset[$i]['topic_status'] == TOPIC_LOCKED ) ? $lang['Topic_locked'] : $lang['No_new_posts'];
@@ -948,16 +1021,17 @@ if ( $mode == 'searchuser' ) {
 
 				$last_post_author = ( $searchset[$i]['id2'] == ANONYMOUS ) ? ( ($searchset[$i]['post_username2'] != '' ) ? $searchset[$i]['post_username2'] . ' ' : $lang['Guest'] . ' ' ) : '<a href="' . getlink('Your_Account&amp;profile=' . $searchset[$i]['id2']) . '">' . $searchset[$i]['user2'] . '</a>';
 
-				$last_post_url = '<a href="' . getlink("&amp;file=viewtopic&amp;"  . POST_POST_URL . '=' . $searchset[$i]['topic_last_post_id']) . '#' . $searchset[$i]['topic_last_post_id'] . '"><img src="' . $images['icon_latest_reply'] . '" alt="' . $lang['View_latest_post'] . '" title="' . $lang['View_latest_post'] . '" /></a>';
+				$last_post_url = '<a href="' . getlink('&amp;file=viewtopic&amp;'  . POST_POST_URL . '=' . $searchset[$i]['topic_last_post_id']) . '#' . $searchset[$i]['topic_last_post_id'] . '"><img src="' . $images['icon_latest_reply'] . '" alt="' . $lang['View_latest_post'] . '" title="' . $lang['View_latest_post'] . '" /></a>';
 
 				$template->assign_block_vars('searchresults', array(
 					'FORUM_NAME' => $searchset[$i]['forum_name'],
 					'FORUM_ID' => $forum_id,
 					'TOPIC_ID' => $topic_id,
+					'TOPIC_ICON' => !empty($topic_icons[$searchset[$i]['icon_id']]) ? '<img src="'.$topic_icons[$searchset[$i]['icon_id']]['icon_url'].'" alt="'.$topic_icons[$searchset[$i]['icon_id']]['icon_name'].'" title="'.$topic_icons[$searchset[$i]['icon_id']]['icon_name'].'" style="vertical-align:middle;" />' : '<img src="images/spacer.gif" style="width:20px; height:20px;" alt="" />',
 					'FOLDER' => $folder_image,
 					'NEWEST_POST_IMG' => $newest_post_img,
 					'TOPIC_FOLDER_IMG' => $folder_image,
-					'GOTO_PAGE' => $goto_page,
+					'GOTO_PAGE' => $goto_page ? $goto_page : false,
 					'REPLIES' => $replies,
 					'TOPIC_TITLE' => $topic_title,
 					'TOPIC_TYPE' => $topic_type,
@@ -976,9 +1050,9 @@ if ( $mode == 'searchuser' ) {
 		}
 
 		$template->assign_vars(array(
-			'PAGINATION' => generate_pagination("&amp;file=search&amp;search_id=$search_id", $total_match_count, $per_page, $start),
+			'PAGINATION' => isset($watch) ? generate_pagination('&amp;file=search&amp;search_id=watch', $total_match_count, $per_page, $start) : (isset($fwatch) ? generate_pagination('&amp;file=search&amp;search_id=fwatch', $total_match_count, $per_page, $start) : generate_pagination('&amp;file=search&amp;search_id='.$search_id, $total_match_count, $per_page, $start)),
 			'PAGE_NUMBER' => sprintf($lang['Page_of'], ( floor( $start / $per_page ) + 1 ), ceil( $total_match_count / $per_page )),
-
+			'L_SELECT' => $lang['Select'],
 			'L_AUTHOR' => $lang['Author'],
 			'L_MESSAGE' => $lang['Message'],
 			'L_FORUM' => $lang['Forum'],
@@ -989,26 +1063,33 @@ if ( $mode == 'searchuser' ) {
 			'L_LASTPOST' => $lang['Last_Post'],
 			'L_POSTED' => $lang['Posted'],
 			'L_SUBJECT' => $lang['Subject'],
+			'L_MARK_ALL' => $lang['Mark_all'],
+			'L_UNMARK_ALL' => $lang['Unmark_all'],
 			'L_GOTO_PAGE' => $lang['Goto_page'],
-			'L_GO' => $lang['Go'])
-		);
+			'L_GO' => $lang['Go'],
+			'S_WATCH_ACTION' => getlink('&amp;file=search')
+		));
 
 		if ( $show_results == 'posts' ) {
 			$template->set_filenames(array('body' => 'forums/search_results_posts.html'));
 		} else {
-			$template->set_filenames(array('body' => 'forums/search_results_topics.html'));
+			if ( isset($watch) ) {
+				$template->set_filenames(array('body' => 'forums/search_results_watch.html'));
+			} elseif (isset($fwatch)) {
+				$template->set_filenames(array('body' => 'forums/search_results_fwatch.html'));
+			} else {
+				$template->set_filenames(array('body' => 'forums/search_results_topics.html'));
+			}
 		}
 
-		require_once("includes/phpBB/page_tail.php");
+		require_once('includes/phpBB/page_tail.php');
 	}
 	else {
 		message_die(GENERAL_MESSAGE, $lang['No_search_match']);
 	}
 }
 
-//
-// Search forum
-//
+# Search forum
 $sql = "SELECT c.cat_title, c.cat_id, f.forum_name, f.forum_id
 	FROM " . CATEGORIES_TABLE . " c, " . FORUMS_TABLE . " f
 	WHERE f.cat_id = c.cat_id
@@ -1038,9 +1119,7 @@ if ( $s_forums != '' )
 {
 	$s_forums = '<option value="-1">' . $lang['All_available'] . '</option>' . $s_forums;
 
-	//
-	// Category to search
-	//
+	# Category to search
 	$s_categories = '<option value="-1">' . $lang['All_available'] . '</option>';
 	while( list($cat_id, $cat_title) = each($list_cat))
 	{
@@ -1052,9 +1131,7 @@ else
 	message_die(GENERAL_MESSAGE, $lang['No_searchable_forums']);
 }
 
-//
-// Number of chars returned
-//
+# Number of chars returned
 $s_characters = '<option value="-1">' . $lang['All_available'] . '</option>';
 $s_characters .= '<option value="0">0</option>';
 $s_characters .= '<option value="25">25</option>';
@@ -1066,18 +1143,14 @@ for($i = 100; $i < 1100 ; $i += 100)
 	$s_characters .= '<option value="' . $i . '"' . $selected . '>' . $i . '</option>';
 }
 
-//
-// Sorting
-//
+# Sorting
 $s_sort_by = "";
 for($i = 0; $i < count($sort_by_types); $i++)
 {
 	$s_sort_by .= '<option value="' . $i . '">' . $sort_by_types[$i] . '</option>';
 }
 
-//
-// Search time
-//
+# Search time
 $previous_days = array(0, 1, 7, 14, 30, 90, 180, 364);
 $previous_days_text = array($lang['All_Posts'], $lang['1_Day'], $lang['7_Days'], $lang['2_Weeks'], $lang['1_Month'], $lang['3_Months'], $lang['6_Months'], $lang['1_Year']);
 
@@ -1088,11 +1161,9 @@ for($i = 0; $i < count($previous_days); $i++)
 	$s_time .= '<option value="' . $previous_days[$i] . '"' . $selected . '>' . $previous_days_text[$i] . '</option>';
 }
 
-//
-// Output the basic page
-//
+# Output the basic page
 $page_title = $lang['Search'];
-require_once("includes/phpBB/page_header.php");
+require_once('includes/phpBB/page_header.php');
 
 make_jumpbox('viewforum');
 
@@ -1120,7 +1191,7 @@ $template->assign_vars(array(
 	'L_TOPICS' => $lang['Topics'],
 	'L_POSTS' => $lang['Posts'],
 
-	'S_SEARCH_ACTION' => getlink("&amp;file=search&amp;mode=results"),
+	'S_SEARCH_ACTION' => getlink('&amp;file=search&amp;mode=results'),
 	'S_CHARACTER_OPTIONS' => $s_characters,
 	'S_FORUM_OPTIONS' => $s_forums,
 	'S_CATEGORY_OPTIONS' => $s_categories,
@@ -1131,4 +1202,4 @@ $template->assign_vars(array(
 
 $template->set_filenames(array('body' => 'forums/search_body.html'));
 
-require_once('includes/phpBB/page_tail.php');
+require_once('includes/phpBB/page_tail.php');
\ No newline at end of file
