@@ -8,93 +8,66 @@
  *
   Last modification notes:
   $Source: /cvs/html/modules/Forums/viewforum.php,v $
-  $Revision: 9.17 $
-  $Author: nanocaiordo $
-  $Date: 2007/12/12 12:54:25 $
+  $Revision: 9.17.2.2 $
+  $Author: phoenix $
+  $Date: 2011/12/13 12:29:27 $
  *
  ***************************************************************************/
 /***************************************************************************
- *
  *	 This program is free software; you can redistribute it and/or modify
  *	 it under the terms of the GNU General Public License as published by
  *	 the Free Software Foundation; either version 2 of the License, or
  *	 (at your option) any later version.
- *
  ***************************************************************************/
 if (!defined('CPG_NUKE')) { exit; }
 require_once('modules/'.$module_name.'/nukebb.php');
 
-//
-// Start initial var setup
-//
+# Start initial var setup
 if (isset($_GET[POST_FORUM_URL]) || isset($_POST[POST_FORUM_URL])) {
 	$forum_id = intval(isset($_GET[POST_FORUM_URL]) ? $_GET[POST_FORUM_URL] : $_POST[POST_FORUM_URL]);
 } else {
 	$forum_id = '';
 }
 $start = (isset($_GET['start']) ? intval($_GET['start']) : 0);
-//
-// Start session management
-//
+# Start session management
 $userdata = session_pagestart($user_ip, $forum_id);
 init_userprefs($userdata);
-//
-// End session management
-//
+# End session management
+# End initial var setup
 
-//
-// End initial var setup
-//
-
-//
-// Check if the user has actually sent a forum ID with his/her request
-// If not give them a nice error page.
-//
+# Check if the user has actually sent a forum ID with his/her request
+# If not give them a nice error page.
 if (is_numeric($forum_id)) {
 	$result = $db->sql_query("SELECT * FROM ".FORUMS_TABLE." f, ".CATEGORIES_TABLE." c
 	WHERE f.forum_id = $forum_id
 	AND f.cat_id = c.cat_id");
 } else {
 	message_die(GENERAL_MESSAGE, $lang['Forum_not_exist']);
-	//cpg_error('Forum_not_exist', GENERAL_MESSAGE);
+	#cpg_error('Forum_not_exist', GENERAL_MESSAGE);
 }
-
-//
-// If the query doesn't return any rows this isn't a valid forum. Inform
-// the user.
-//
+# If the query doesn't return any rows this isn't a valid forum. Inform the user
 if (!($forum_row = $db->sql_fetchrow($result))) {
 	message_die(GENERAL_MESSAGE, $lang['Forum_not_exist']);
-	//cpg_error('Forum_not_exist', GENERAL_MESSAGE);
+	#cpg_error('Forum_not_exist', GENERAL_MESSAGE);
 }
-
-
-
-//
-// Start auth check
-//
+if ($forum_row['forum_type'] == 3) {
+	url_redirect($forum_row['forum_link']);
+}
+# Start auth check
 $is_auth = array();
 $is_auth = auth(AUTH_ALL, $forum_id, $userdata, $forum_row);
-
 if (!$is_auth['auth_read'] || !$is_auth['auth_view']) {
 	if (!is_user()) {
 		url_redirect(getlink('Your_Account'), true);
 	}
-	//
-	// The user is not authed to read this forum ...
-	//
+	# The user is not authed to read this forum ...
 	$message = (!$is_auth['auth_view']) ? $lang['Forum_not_exist'] : sprintf($lang['Sorry_auth_read'], $is_auth['auth_read_type']);
 	message_die(GENERAL_MESSAGE, $message);
 	//cpg_error($message, GENERAL_MESSAGE);
-
 }
-//
-// End of auth check
-//
+# End of auth check
 
-//
-// Handle marking posts
-//
+# Handle marking posts
 if (isset($_GET['mark']) || isset($_POST['mark'])) {
 	$mark_read = (isset($_POST['mark'])) ? $_POST['mark'] : $_GET['mark'];
 	if ($mark_read == 'topics') {
@@ -107,16 +80,14 @@ if (isset($_GET['mark']) || isset($_POST['mark'])) {
 		//cpg_error($message, GENERAL_MESSAGE);
 	}
 }
-//
-// End handle marking posts
-//
+# End handle marking posts
 
 $tracking_topics = isset($CPG_SESS[$module_name]['track_topics']) ? $CPG_SESS[$module_name]['track_topics'] : array();
 $tracking_forums = isset($CPG_SESS[$module_name]['track_forums']) ? $CPG_SESS[$module_name]['track_forums'] : array();
+$url_info = '&amp;start='.$start;
+$watching_forums = forum_watch($forum_id, $url_info);
 
-//
-// Do the forum Prune
-//
+# Do the forum Prune
 if ($is_auth['auth_mod'] && $board_config['prune_enable']) {
 	if ($forum_row['prune_next'] < gmtime() && $forum_row['prune_enable']) {
 		require_once('includes/phpBB/prune.php');
@@ -124,14 +95,19 @@ if ($is_auth['auth_mod'] && $board_config['prune_enable']) {
 		auto_prune($forum_id);
 	}
 }
-//
-// End of forum prune
-//
+# End of forum prune
 
-//
-// Obtain list of moderators of each forum
-// First users, then groups ... broken into two queries
-//
+# Do the forum Archive
+if ($is_auth['auth_mod'] && $board_config['archive_enable']) {
+	if ($forum_row['archive_next'] < gmtime() && $forum_row['archive_enable']) {
+		require_once('includes/phpBB/archive.php');
+		require_once('includes/phpBB/functions_admin.php');
+		auto_archive($forum_id);
+	}
+}
+# End of forum archive
+
+# Obtain list of moderators of each forum, first users, then groups - 2 queries
 $moderators = array();
 if (!cache_load_array('forum_moderators', $module_name)) {
 	$sql = "SELECT u.user_id, u.username
@@ -143,7 +119,7 @@ if (!cache_load_array('forum_moderators', $module_name)) {
 		ORDER BY u.user_id";
 	$result = $db->sql_query($sql);
 	while( $row = $db->sql_fetchrow($result, SQL_ASSOC) ) {
-	$moderators[] = '<a href="'.getlink("Your_Account&amp;profile=".$row['user_id']).'">'.$row['username'].'</a>';
+	$moderators[] = '<a href="'.getlink('Your_Account&amp;profile='.$row['user_id']).'">'.$row['username'].'</a>';
 	}
 	$db->sql_freeresult($result);
 
@@ -159,29 +135,25 @@ if (!cache_load_array('forum_moderators', $module_name)) {
 		ORDER BY g.group_id";
 	$result = $db->sql_query($sql);
 	while( $row = $db->sql_fetchrow($result, SQL_ASSOC) ) {
-	$moderators[] = '<a href="'.getlink("Groups&amp;".POST_GROUPS_URL."=".$row['group_id']).'">'.$row['group_name'].'</a>';
+	$moderators[] = '<a href="'.getlink('Groups&amp;'.POST_GROUPS_URL.'='.$row['group_id']).'">'.$row['group_name'].'</a>';
 	}
 	$db->sql_freeresult($result);
-} else {
+} elseif (isset($forum_moderators[$forum_id])) {
 	$moderators = $forum_moderators[$forum_id];
 }
-
 $l_moderators = ( count($moderators) == 1 ) ? $lang['Moderator'] : $lang['Moderators'];
-$forum_moderators = ( count($moderators) ) ? implode(', ', $moderators) : $lang['None'];
+$forum_moderators2 = ( count($moderators) ) ? implode(', ', $moderators) : $lang['None'];
 unset($moderators);
 
-//
-// Generate a 'Show topics in previous x days' select box. If the topicsdays var is sent
-// then get it's value, find the number of topics with dates newer than it (to properly
-// handle pagination) and alter the main query
-//
+# Generate a 'Show topics in previous x days' select box. If the topicsdays var is sent
+# then get it's value, find the number of topics with dates newer than it (to properly
+# handle pagination) and alter the main query
 $previous_days = array(0, 1, 7, 14, 30, 91, 182, 364);
 $previous_days_text = array($lang['All_Topics'], $lang['1_Day'], $lang['7_Days'], $lang['2_Weeks'], $lang['1_Month'], $lang['3_Months'], $lang['6_Months'], $lang['1_Year']);
 
 if (!empty($_POST['topicdays']) || !empty($_GET['topicdays'])) {
 	$topic_days = intval(empty($_POST['topicdays']) ? $_GET['topicdays'] : $_POST['topicdays']);
 	$min_topic_time = gmtime() - ($topic_days * 86400);
-
 	$sql = "SELECT COUNT(t.topic_id) AS forum_topics
 			FROM ".TOPICS_TABLE." t, ".POSTS_TABLE." p
 			WHERE t.forum_id = $forum_id
@@ -190,10 +162,8 @@ if (!empty($_POST['topicdays']) || !empty($_GET['topicdays'])) {
 	$result = $db->sql_query($sql);
 	$row = $db->sql_fetchrow($result, SQL_ASSOC);
 	$db->sql_freeresult($result);
-
 	$topics_count = ( $row['forum_topics'] ) ? $row['forum_topics'] : 1;
 	$limit_topics_time = "AND p.post_time >= $min_topic_time";
-
 	if (!empty($_POST['topicdays'])) { $start = 0; }
 } else {
 	$topics_count = ($forum_row['forum_topics']) ? $forum_row['forum_topics'] : 1;
@@ -208,11 +178,7 @@ for($i = 0; $i < count($previous_days); $i++) {
 }
 $select_topic_days .= '</select>';
 
-
-//
-// All announcement data, this keeps announcements
-// on each viewforum page ...
-//
+# All announcement data, this keeps announcements on each viewforum page ...
 $sql = "SELECT t.*, u.username, u.user_id, u2.username as user2, u2.user_id as id2, p.post_time, p.post_username
 		FROM ".TOPICS_TABLE." t, ".USERS_TABLE." u, ".POSTS_TABLE." p, ".USERS_TABLE." u2
 		WHERE t.forum_id = $forum_id
@@ -220,7 +186,6 @@ $sql = "SELECT t.*, u.username, u.user_id, u2.username as user2, u2.user_id as i
 			AND p.poster_id = u2.user_id AND t.topic_type = ".POST_ANNOUNCE."
 		ORDER BY t.topic_last_post_id DESC ";
 $result = $db->sql_query($sql);
-
 $topic_rowset = array();
 $total_announcements = 0;
 while( $row = $db->sql_fetchrow($result) ) {
@@ -229,13 +194,7 @@ while( $row = $db->sql_fetchrow($result) ) {
 }
 $db->sql_freeresult($result);
 
-// TopicIcon_mod
-$topic_icons = get_topic_icons($forum_id);
-
-//
-// Grab all the basic data (all topics except announcements)
-// for this forum
-//
+# Grab all the basic data (all topics except announcements) for this forum
 $sql = "SELECT t.*, u.username, u.user_id, u2.username as user2, u2.user_id as id2, p.post_username, p2.post_username AS post_username2, p2.post_time
 		FROM ".TOPICS_TABLE." t, ".USERS_TABLE." u, ".POSTS_TABLE." p, ".POSTS_TABLE." p2, ".USERS_TABLE." u2
 		WHERE t.forum_id = $forum_id
@@ -255,44 +214,33 @@ while( $row = $db->sql_fetchrow($result) ) {
 }
 $db->sql_freeresult($result);
 
-//
-// Total topics ...
-//
+# Total topics ...
 $total_topics += $total_announcements;
 
-//
-// Define censored word matches
-//
+# Define censored word matches
 $orig_word = array();
 $replacement_word = array();
 obtain_word_list($orig_word, $replacement_word);
 
-//
-// User authorisation levels output
-//
+# User authorisation levels output
 $s_auth_can	 = (($is_auth['auth_post']) ? $lang['Rules_post_can'] : $lang['Rules_post_cannot']).'<br />';
 $s_auth_can .= (($is_auth['auth_reply']) ? $lang['Rules_reply_can'] : $lang['Rules_reply_cannot']).'<br />';
 $s_auth_can .= (($is_auth['auth_edit']) ? $lang['Rules_edit_can'] : $lang['Rules_edit_cannot']).'<br />';
 $s_auth_can .= (($is_auth['auth_delete']) ? $lang['Rules_delete_can'] : $lang['Rules_delete_cannot']).'<br />';
 $s_auth_can .= (($is_auth['auth_vote']) ? $lang['Rules_vote_can'] : $lang['Rules_vote_cannot']).'<br />';
-//if (defined('BBAttach_mod')) {
-	attach_build_auth_levels($is_auth, $s_auth_can);
+attach_build_auth_levels($is_auth, $s_auth_can);
 
 if ($is_auth['auth_mod']) {
-	$s_auth_can .= sprintf($lang['Rules_moderate'], '<a href="' .getlink("&amp;file=modcp&amp;".POST_FORUM_URL."=$forum_id").'">', '</a>');
+	$s_auth_can .= sprintf($lang['Rules_moderate'], '<a href="' .getlink('&amp;file=modcp&amp;'.POST_FORUM_URL."=$forum_id").'">', '</a>');
 }
 
-//
-// Mozilla navigation bar
-//
+# Mozilla navigation bar
 $nav_links['up'] = array(
 	'url' => getlink(),
 	'title' => sprintf($lang['Forum_Index'], $board_config['sitename'])
 );
 
-//
-// Dump out the page header and load viewforum template
-//
+# Dump out the page header and load viewforum template
 $page_title = !empty($forum_row['cat_title']) ? $forum_row['cat_title']: '';
 $page_title .= !empty($forum_row['forum_name']) ? ' '._BC_DELIM.' '. $forum_row['forum_name'] : '';
 require_once('includes/phpBB/page_header.php');
@@ -306,7 +254,7 @@ if ($forum_row['forum_type'] == 1) {
 		'L_TOPICS' => $lang['Topics'],
 		'L_POSTS' => $lang['Posts'],
 		'L_LAST_POST' => $lang['Last_Post'],
-		'U_MARK_READ' => getlink("&amp;mark=forums"),
+		'U_MARK_READ' => getlink('&amp;mark=forums'),
 	));
 	for($j = 0; $j < count($forum_data); $j++) {
 		$sub_forum_id = $forum_data[$j]['forum_id'];
@@ -315,7 +263,8 @@ if ($forum_row['forum_type'] == 1) {
 		} else if ($forum_data[$j]['forum_type'] == 3) {
 			$forumlink = $forum_data[$j]['forum_link'];
 		} else {
-			$forumlink = getlink("&amp;file=viewforum&amp;".POST_FORUM_URL."=$sub_forum_id");
+			$forumlink = getlink('&amp;file=viewforum&amp;'.POST_FORUM_URL.'='.$sub_forum_id);
+			$archivelink = getlink('&amp;file=viewarchive&amp;'.POST_FORUM_URL.'='.$forum_id);
 		}
 		$template->assign_block_vars('forumrow', array(
 			'S_IS_CAT'			 => false,
@@ -327,30 +276,54 @@ if ($forum_row['forum_type'] == 1) {
 			'FORUM_DESC'		 => $forum_data[$j]['forum_desc'],
 			'POSTS'				 => $forum_data[$j]['forum_posts'],
 			'TOPICS'			 => $forum_data[$j]['forum_topics'],
+			'POSTS_ARCHIVED'	 => $forum_data[$j]['archive_posts'],
+			'TOPICS_ARCHIVED'	 => $forum_data[$j]['archive_topics'],
 			'LAST_POST_TIME'	 => ($forum_data[$j]['forum_last_post_id'] ) ? create_date($board_config['default_dateformat'], $forum_data[$j]['post_time']) : '',
 			'LAST_POSTER'		 => ($forum_data[$j]['username']) ? $forum_data[$j]['username'] : $lang['Guest'],
 			'MODERATORS'		 => $forum_data[$j]['moderator_list'],
-//			'SUBFORUMS'		  => $subforums_list,
-
-//			'L_SUBFORUM_STR'	 => $l_subforums,
+			'SUB_FORUMS'		 => ($forum_data[$j]['forum_type'] == 1),
+			'SUBFORUMS'			 => $forum_data[$j]['subforums_list'],
+			'L_SUBFORUM_STR'	 => $forum_data[$j]['subforums_lang'],
 			'L_MODERATOR_STR' => $forum_data[$j]['l_moderators'],
 			'L_FORUM_FOLDER_ALT' => $forum_data[$j]['folder_alt'],
 			'BC_DELIM'		  => _BC_DELIM,
-			'U_LAST_POSTER'	  => ($forum_data[$j]['user_id'] > ANONYMOUS) ? getlink("Your_Account&amp;profile=".$forum_data[$j]['user_id']) : '',
-			'U_LAST_POST'	  => ($forum_data[$j]['forum_last_post_id']) ? getlink("&amp;file=viewtopic&amp;" .POST_POST_URL.'='.$forum_data[$j]['forum_last_post_id']).'#'.$forum_data[$j]['forum_last_post_id'] : '',
-			'U_VIEWFORUM'	  => $forumlink
+			'U_LAST_POSTER'	  => ($forum_data[$j]['user_id'] > ANONYMOUS) ? getlink('Your_Account&amp;profile='.$forum_data[$j]['user_id']) : '',
+			'U_LAST_POST'	  => ($forum_data[$j]['forum_last_post_id']) ? getlink('&amp;file=viewtopic&amp;' .POST_POST_URL.'='.$forum_data[$j]['forum_last_post_id']).'#'.$forum_data[$j]['forum_last_post_id'] : '',
+			'U_VIEWFORUM'		 => $forumlink,
+			'U_VIEWARCHIVE'		 => !empty($forum_data[$j]['archive_topics']) ? $archivelink : ''
 			)
 		);
 	}
 }
 
+if ($forum_row['parent_id'] != 0) {
+	$is_subforum = true;
+	$parent_id = $forum_row['parent_id'];
+	$parents = array();
+	while ($parent_id != 0) {
+		list ($parent_name, $parent_id, $parent_forum_id) = $db->sql_ufetchrow("SELECT forum_name AS parent_name, parent_id, forum_id FROM ".FORUMS_TABLE." 
+		WHERE forum_id = $parent_id", SQL_NUM);
+		$parents[] = '<a href="'.getlink('&amp;file=viewforum&amp;f='.$parent_forum_id).'">'.$parent_name.'</a>';
+	}
+	$parents = array_reverse($parents);
+	$parents_list = implode(' '._BC_DELIM.' ', $parents);
+} else {
+	$is_subforum = false;
+	$parents_list = '';
+}
+$forum_watch_url = ((is_user() && !$watching_forums && $board_config['allow_forum_watch']) ? getlink('&amp;file=viewforum&amp;f='.$forum_id.'&amp;watch=forum'.$url_info) : '');
+$forum_unwatch_url = ((is_user() && $watching_forums && $board_config['allow_forum_watch']) ? getlink('&amp;file=viewforum&amp;f='.$forum_id.'&amp;unwatch=forum'.$url_info) : '');
+
 $template->assign_vars(array(
+	'IS_SUBFORUM' => $is_subforum,
+	'SUB_PARENTS' => $parents_list,
 	'SUB_FORUMS' => ($forum_row['forum_type'] == 1),
 	'FORUM_ID' => $forum_id,
 	'FORUM_NAME' => $forum_row['forum_name'],
 	'FORUM_DESC' => $forum_row['forum_desc'],
-	'MODERATORS' => $forum_moderators,
-	'POST_IMG' => ( $forum_row['forum_status'] == FORUM_LOCKED ) ? $images['post_locked'] : $images['post_new'],
+	'VIEW_ARCHIVES'	 => $forum_row['archive_topics'] > 0 ? true: false,
+	'MODERATORS' => $forum_moderators2,
+	'POST_IMG' => ($forum_row['forum_status'] == FORUM_LOCKED) ? $images['post_locked'] : $images['post_new'],
 	'BC_DELIM' => _BC_DELIM,
 	'FOLDER_IMG' => $images['folder'],
 	'FOLDER_NEW_IMG' => $images['folder_new'],
@@ -362,7 +335,7 @@ $template->assign_vars(array(
 	'FOLDER_STICKY_NEW_IMG' => $images['folder_sticky_new'],
 	'FOLDER_ANNOUNCE_IMG' => $images['folder_announce'],
 	'FOLDER_ANNOUNCE_NEW_IMG' => $images['folder_announce_new'],
-
+	'L_VIEW_ARCHIVES' => $lang['View_Archives'],
 	'L_TOPICS' => $lang['Topics'],
 	'L_REPLIES' => $lang['Replies'],
 	'L_VIEWS' => $lang['Views'],
@@ -370,7 +343,7 @@ $template->assign_vars(array(
 	'L_LASTPOST' => $lang['Last_Post'],
 	'L_MODERATOR' => $l_moderators,
 	'L_MARK_TOPICS_READ' => $lang['Mark_all_topics'],
-	'L_POST_NEW_TOPIC' => ( $forum_row['forum_status'] == FORUM_LOCKED ) ? $lang['Forum_locked'] : $lang['Post_new_topic'],
+	'L_POST_NEW_TOPIC' => ($forum_row['forum_status'] == FORUM_LOCKED) ? $lang['Forum_locked'] : $lang['Post_new_topic'],
 	'L_NO_POSTS' => $lang['No_Posts'],
 	'L_NO_NEW_POSTS' => $lang['No_new_posts'],
 	'L_NEW_POSTS' => $lang['New_posts'],
@@ -385,45 +358,42 @@ $template->assign_vars(array(
 	'L_AUTHOR' => $lang['Author'],
 	'L_DISPLAY_TOPICS' => $lang['Display_topics'],
 	'L_GO' => $lang['Go'],
-
+	'L_FORUM_WATCH' => $lang['Start_watching_forum'],
+	'L_FORUM_UNWATCH' => $lang['Stop_watching_forum'],
 	'S_AUTH_LIST' => $s_auth_can,
 	'S_SELECT_TOPIC_DAYS' => $select_topic_days,
-	'S_POST_DAYS_ACTION' => getlink("&amp;file=viewforum&amp;".POST_FORUM_URL."=".$forum_id."&amp;start=$start"),
-
-	'U_MARK_READ' => getlink("&amp;file=viewforum&amp;".POST_FORUM_URL."=$forum_id&amp;mark=topics"),
-	'U_POST_NEW_TOPIC' => getlink("&amp;file=posting&amp;mode=newtopic&amp;".POST_FORUM_URL."=$forum_id"),
-	'U_VIEW_FORUM' => getlink("&amp;file=viewforum&amp;".POST_FORUM_URL ."=$forum_id")
+	'S_POST_DAYS_ACTION' => getlink('&amp;file=viewforum&amp;'.POST_FORUM_URL.'='.$forum_id."&amp;start=$start"),
+	'U_VIEW_ARCHIVES' => getlink('&amp;file=viewarchive&amp;'.POST_FORUM_URL."=$forum_id"),
+	'U_MARK_READ' => getlink('&amp;file=viewforum&amp;'.POST_FORUM_URL."=$forum_id&amp;mark=topics"),
+	'U_POST_NEW_TOPIC' => getlink('&amp;file=posting&amp;mode=newtopic&amp;'.POST_FORUM_URL."=$forum_id"),
+	'U_VIEW_FORUM' => getlink('&amp;file=viewforum&amp;'.POST_FORUM_URL ."=$forum_id"),
+	'U_FORUM_WATCH' => $forum_watch_url,
+	'U_FORUM_UNWATCH' => $forum_unwatch_url
 	)
 );
 make_jumpbox('viewforum');
-//
-// End header
-//
+# End header
 
-//
-// Okay, lets dump out the page ...
-//
+# Okay, lets dump out the page ...
 if ($total_topics) {
 	$announces = $stickies = $normalposts = false;
 	for ($i = 0; $i < $total_topics; $i++) {
 		$topic_id = $topic_rowset[$i]['topic_id'];
-
 		$topic_title = (count($orig_word)) ? preg_replace($orig_word, $replacement_word, $topic_rowset[$i]['topic_title']) : $topic_rowset[$i]['topic_title'];
-
 		$replies = $topic_rowset[$i]['topic_replies'];
-
 		$topic_type = $topic_rowset[$i]['topic_type'];
 
-// TopicIcon_mod
-		//grab this topic's icon_id
+# TopicIcon_mod
+		#grab this topic's icon_id
 		$topic_icon_id = $topic_rowset[$i]['icon_id'];
 		$topic_icon_source = '<img width="20" src="images/spacer.gif" alt="" />';
-		//if we have an icon
+		#if we have an icon
 		if ($topic_icon_id != NULL && $topic_icon_id != 0) {
-			//create the path
+			#create the path
 			$topic_icon_source = '<img src="'.$topic_icons[$topic_icon_id]['icon_url'].'" alt="'.$topic_icons[$topic_icon_id]['icon_name'].'" title="'.$topic_icons[$topic_icon_id]['icon_name'].'" align="middle" />';
 		}
-// TopicIcon_mod end
+# TopicIcon_mod end
+
 		if ($topic_type == POST_ANNOUNCE) {
 			$topic_type = '';
 			$topics_header = (!$announces) ? $lang['Post_Announcement'] : '';
@@ -437,11 +407,9 @@ if ($total_topics) {
 			$topics_header = (!$normalposts) ? $lang['Post_Normal'] : '';
 			$normalposts = true;
 		}
-
 		if ($topic_rowset[$i]['topic_vote']) {
 			$topic_type .= $lang['Topic_Poll'].' ';
 		}
-
 		if ($topic_rowset[$i]['topic_status'] == TOPIC_MOVED) {
 			$topic_type = $lang['Topic_Moved'].' ';
 			$topic_id = $topic_rowset[$i]['topic_moved_id'];
@@ -491,7 +459,7 @@ if ($total_topics) {
 						if ($unread_topics) {
 							$folder_image = $folder_new;
 							$folder_alt = $lang['New_posts'];
-							$newest_post_img = '<a href="'.getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id&amp;view=newest").'"><img src="'.$images['icon_newest_reply'].'" alt="'.$lang['View_newest_post'].'" title="'.$lang['View_newest_post'].'" /></a> ';
+							$newest_post_img = '<a href="'.getlink('&amp;file=viewtopic&amp;'.POST_TOPIC_URL."=$topic_id&amp;view=newest").'"><img src="'.$images['icon_newest_reply'].'" alt="'.$lang['View_newest_post'].'" title="'.$lang['View_newest_post'].'" /></a> ';
 						} else {
 							$folder_image = $folder;
 							$folder_alt = ( $topic_rowset[$i]['topic_status'] == TOPIC_LOCKED ) ? $lang['Topic_locked'] : $lang['No_new_posts'];
@@ -500,7 +468,7 @@ if ($total_topics) {
 					} else {
 						$folder_image = $folder_new;
 						$folder_alt = ( $topic_rowset[$i]['topic_status'] == TOPIC_LOCKED ) ? $lang['Topic_locked'] : $lang['New_posts'];
-						$newest_post_img = '<a href="'.getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id&amp;view=newest").'"><img src="'.$images['icon_newest_reply'].'" alt="'.$lang['View_newest_post'].'" title="'.$lang['View_newest_post'].'" /></a> ';
+						$newest_post_img = '<a href="'.getlink('&amp;file=viewtopic&amp;'.POST_TOPIC_URL."=$topic_id&amp;view=newest").'"><img src="'.$images['icon_newest_reply'].'" alt="'.$lang['View_newest_post'].'" title="'.$lang['View_newest_post'].'" /></a> ';
 					}
 				} else {
 					$folder_image = $folder;
@@ -519,7 +487,7 @@ if ($total_topics) {
 			$goto_page = ' [ <img src="'.$images['icon_gotopost'].'" alt="'.$lang['Goto_page'].'" title="'.$lang['Goto_page'].'" />'.$lang['Goto_page'].': ';
 			$times = 1;
 			for ($j = 0; $j < $replies + 1; $j += $board_config['posts_per_page']) {
-				$goto_page .= '<a href="'.getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=".$topic_id."&amp;start=$j").'">'.$times.'</a>';
+				$goto_page .= '<a href="'.getlink('&amp;file=viewtopic&amp;'.POST_TOPIC_URL.'='.$topic_id."&amp;start=$j").'">'.$times.'</a>';
 				if ($times == 1 && $total_pages > 4) {
 					$goto_page .= ' ... ';
 					$times = $total_pages - 3;
@@ -534,9 +502,9 @@ if ($total_topics) {
 			$goto_page = '';
 		}
 
-		$view_topic_url = getlink("&amp;file=viewtopic&amp;".POST_TOPIC_URL."=$topic_id");
+		$view_topic_url = getlink('&amp;file=viewtopic&amp;'.POST_TOPIC_URL."=$topic_id");
 
-		$topic_author  = ($topic_rowset[$i]['user_id'] != ANONYMOUS) ? '<a href="'.getlink("Your_Account&amp;profile=".$topic_rowset[$i]['user_id']).'">' : '';
+		$topic_author  = ($topic_rowset[$i]['user_id'] != ANONYMOUS) ? '<a href="'.getlink('Your_Account&amp;profile='.$topic_rowset[$i]['user_id']).'">' : '';
 		$topic_author .= ($topic_rowset[$i]['user_id'] != ANONYMOUS) ? $topic_rowset[$i]['username'] : (($topic_rowset[$i]['post_username'] != '') ? $topic_rowset[$i]['post_username'] : $lang['Guest']);
 		$topic_author .= ($topic_rowset[$i]['user_id'] != ANONYMOUS) ? '</a>' : '';
 
@@ -554,20 +522,16 @@ if ($total_topics) {
 			'GOTO_PAGE' => $goto_page,
 			'REPLIES' => $replies,
 			'NEWEST_POST_IMG' => $newest_post_img,
-// BBAttach_mod
 			'TOPIC_ATTACHMENT_IMG' => topic_attachment_image($topic_rowset[$i]['topic_attachment']),
 			'TOPIC_TITLE' => $topic_title,
 			'TOPIC_TYPE' => $topic_type,
 			'VIEWS' => $topic_rowset[$i]['topic_views'],
 			'FIRST_POST_TIME' => create_date($board_config['default_dateformat'], $topic_rowset[$i]['topic_time']),
 			'LAST_POST_TIME' => create_date($board_config['default_dateformat'], $topic_rowset[$i]['post_time']),
-			'LAST_POST_AUTHOR' => ($topic_rowset[$i]['id2'] == ANONYMOUS) ? (($topic_rowset[$i]['post_username2'] != '') ? $topic_rowset[$i]['post_username2'].' ' : $lang['Guest'].' ' ) : '<a href="'.getlink("Your_Account&amp;profile=".$topic_rowset[$i]['id2']).'">'.$topic_rowset[$i]['user2'].'</a>',
-			'LAST_POST_IMG' => '<a href="'.getlink("&amp;file=viewtopic&amp;".POST_POST_URL.'='.$topic_rowset[$i]['topic_last_post_id']).'#'.$topic_rowset[$i]['topic_last_post_id'].'"><img src="'.$images['icon_latest_reply'].'" alt="'.$lang['View_latest_post'].'" title="'.$lang['View_latest_post'].'" /></a>',
-
+			'LAST_POST_AUTHOR' => ($topic_rowset[$i]['id2'] == ANONYMOUS) ? (($topic_rowset[$i]['post_username2'] != '') ? $topic_rowset[$i]['post_username2'].' ' : $lang['Guest'].' ' ) : '<a href="'.getlink('Your_Account&amp;profile='.$topic_rowset[$i]['id2']).'">'.$topic_rowset[$i]['user2'].'</a>',
+			'LAST_POST_IMG' => '<a href="'.getlink('&amp;file=viewtopic&amp;'.POST_POST_URL.'='.$topic_rowset[$i]['topic_last_post_id']).'#'.$topic_rowset[$i]['topic_last_post_id'].'"><img src="'.$images['icon_latest_reply'].'" alt="'.$lang['View_latest_post'].'" title="'.$lang['View_latest_post'].'" /></a>',
 			'L_TOPIC_FOLDER_ALT' => $folder_alt,
-// TopicIcon_mod
 			'TOPIC_ICON' => $topic_icon_source,
-
 			'U_VIEW_TOPIC' => $view_topic_url)
 		);
 	}
@@ -575,26 +539,22 @@ if ($total_topics) {
 	if ($topics_count > $total_announcements) { $topics_count -= $total_announcements; }
 
 	$template->assign_vars(array(
-		'PAGINATION' => generate_pagination("&amp;file=viewforum&amp;".POST_FORUM_URL."=$forum_id&amp;topicdays=$topic_days", $topics_count, $board_config['topics_per_page'], $start),
+		'PAGINATION' => generate_pagination('&amp;file=viewforum&amp;'.POST_FORUM_URL."=$forum_id&amp;topicdays=$topic_days", $topics_count, $board_config['topics_per_page'], $start),
 		'PAGE_NUMBER' => sprintf($lang['Page_of'], ( floor( $start / $board_config['topics_per_page'] ) + 1 ), ceil( $topics_count / $board_config['topics_per_page'] )),
 		'L_GOTO_PAGE' => $lang['Goto_page'])
 	);
 } else {
-	//
-	// No topics
-	//
+	# No topics
 	$template->assign_vars(array(
+		'PAGINATION'	=> '',
+		'PAGE_NUMBER'	=> '',
 		'L_NO_TOPICS' => ( $forum_row['forum_status'] == FORUM_LOCKED ) ? $lang['Forum_locked'] : $lang['No_topics_post_one'])
 	);
 	$template->assign_block_vars('switch_no_topics', array() );
 }
 
-//
-// Parse the page and print
-//
+# Parse the page and print
 $template->set_filenames(array('body' => 'forums/viewforum_body.html'));
 
-//
-// Page footer
-//
-require_once('includes/phpBB/page_tail.php');
+# Page footer
+require_once('includes/phpBB/page_tail.php');
\ No newline at end of file
