@@ -9,12 +9,12 @@
   of the GNU GPL version 2 or any later version
 
   $Source: /cvs/html/modules/Your_Account/blocks/news.php,v $
-  $Revision: 9.3 $
-  $Author: djmaze $
-  $Date: 2006/01/06 13:11:11 $
+  $Revision: 9.3.8.1 $
+  $Author: nanocaiordo $
+  $Date: 2008/08/26 12:46:56 $
 **********************************************/
 if (!defined('CPG_NUKE')) { exit; }
-
+if (is_user()) {
 // Last 10 Submissions
 $result = $db->sql_query("SELECT sid, title FROM ".$prefix."_stories WHERE informant='$username' ORDER BY sid DESC LIMIT 0,10");
 if ($db->sql_numrows($result) > 0) {
@@ -26,4 +26,5 @@ if ($db->sql_numrows($result) > 0) {
 	}
 	echo '</ul></div>';
 	CloseTable();
+}
 }
\ No newline at end of file
