@@ -14,9 +14,9 @@
   **************************************************************************  
   Last modification notes:
   $Source: /cvs/html/modules/coppermine/db_input.php,v $
-  $Revision: 9.25 $
+  $Revision: 9.25.2.1 $
   $Author: nanocaiordo $
-  $Date: 2007/12/12 12:54:31 $
+  $Date: 2011/03/15 10:48:34 $
 ****************************************************************************/
 if (!defined('CPG_NUKE')) { exit; }
 
@@ -456,13 +456,14 @@ switch ($event) {
 			cpg_die(_ERROR, $ERROR, __FILE__, __LINE__);
 		}
 		// Create thumbnail and intermediate image and add the image into the DB
-		if (!add_picture($album, $dest_dir, basename($uploaded_pic), $title, $caption, $keywords, $user1, $user2, $user3, $user4, $category, $watermark, $tmpfile)) {
+		$nextid = 0;
+		if (!add_picture($album, $dest_dir, basename($uploaded_pic), $title, $caption, $keywords, $user1, $user2, $user3, $user4, $category, $watermark, $tmpfile, $nextid)) {
 			unlink($uploaded_pic);
 			unlink($tmpfile);
 			cpg_die(_CRITICAL_ERROR, sprintf(ERR_INSERT_PIC, $uploaded_pic) . '<br /><br />' . $ERROR, __FILE__, __LINE__, true);
 		}
 		unlink($tmpfile);
-		$redirect = ($PIC_NEED_APPROVAL) ? getlink() : getlink("&amp;file=displayimage&amp;pid=".$db->sql_nextid('pid'));
+		$redirect = ($PIC_NEED_APPROVAL) ? getlink() : getlink('&amp;file=displayimage&amp;pid='.$nextid);
 		pageheader(INFO, $redirect);
 		msg_box(INFO, UPLOAD_SUCCESS, CONTINU, $redirect);
 		pagefooter();
